@@ -42,6 +42,7 @@ proc Backup {fn} {
 	    BackupFrame $ch $ff $dir
 	}
     }
+    puts $ch "set ds9(seq) $ds9(seq)"
 
     # Geometry
     BackupGUI $ch
@@ -290,16 +291,37 @@ proc BackupFrame {ch which dir} {
     puts $ch "CreateNameNumberFrame $which $type"
     switch -- $type {
 	base {BackupFrameLoad $ch $which $fdir $rdir {}}
-	3d {
-	    BackupFrameLoad $ch $which $fdir $rdir {}
-	    puts $ch "3DDialog"
-	}
 	rgb {
+	    set rr [$which get rgb channel]
 	    foreach cc {{} red green blue} {
 		BackupFrameLoad $ch $which $fdir $rdir $cc
 	    }
+	    $which rgb channel $rr
+
 	    puts $ch "RGBDialog"
 	}
+	hsv {
+	    set rr [$which get hsv channel]
+	    foreach cc {{} hue saturation value} {
+		BackupFrameLoad $ch $which $fdir $rdir $cc
+	    }
+	    $which hsv channel $rr
+
+	    puts $ch "HSVDialog"
+	}
+	hls {
+	    set rr [$which get hls channel]
+	    foreach cc {{} hue lightness saturation} {
+		BackupFrameLoad $ch $which $fdir $rdir $cc
+	    }
+	    $which hls channel $rr
+
+	    puts $ch "HLSDialog"
+	}
+	3d {
+	    BackupFrameLoad $ch $which $fdir $rdir {}
+	    puts $ch "3DDialog"
+	}
     }
 
     MagnifierFrameBackup $ch $which
@@ -308,6 +330,8 @@ proc BackupFrame {ch which dir} {
     DS9Backup $ch $which
     CubeBackup $ch $which
     RGBBackup $ch $which
+    HSVBackup $ch $which
+    HLSBackup $ch $which
     BinBackup $ch $which
     ScaleBackup $ch $which
     # Block need to be before WCS and Crop
@@ -369,11 +393,44 @@ proc BackupFrameLoadParam {varname ch which fdir rdir channel} {
 	return
     }
     
-    if {$channel != {}} {
-	puts $ch "$which rgb channel $channel"
+    array set param [array get $varname]
+
+    set type [$which get type]
+    switch $type {
+	base {}
+	rgb {
+	    switch $param(file,mode) {
+		{rgb image} -
+		{rgb cube} {}
+		{} {
+		    $which rgb channel $channel
+		    puts $ch "$which rgb channel $channel"
+		}
+	    }
+	}
+	hls {
+	    switch $param(file,mode) {
+		{hls image} -
+		{hls cube} {}
+		{} {
+		    $which hls channel $channel
+		    puts $ch "$which hls channel $channel"
+		}
+	    }
+	}
+	hsv {
+	    switch $param(file,mode) {
+		{hsv image} -
+		{hsv cube} {}
+		{} {
+		    $which hsv channel $channel
+		    puts $ch "$which hsv channel $channel"
+		}
+	    }
+	}
+	3d {}
     }
 
-    array set param [array get $varname]
     switch $param(load,type) {
 	mmap -
 	mmapincr -
@@ -544,6 +601,8 @@ proc BackupFrameLoadAlloc {which varname fdir rdir} {
 		    $which save fits rgb cube file \"$ffn\"
 		    set param(file,mode) {rgb cube}
 		}
+		hsv {}
+		hls {}
 	    }
 	}
     }
@@ -637,6 +696,14 @@ proc BackupGUI {ch} {
     puts $ch "global rgb"
     puts $ch "array set rgb \{ [array get rgb] \}"
 
+    global hsv
+    puts $ch "global hsv"
+    puts $ch "array set hsv \{ [array get hsv] \}"
+
+    global hls
+    puts $ch "global hls"
+    puts $ch "array set hls \{ [array get hls] \}"
+
     global threed
     puts $ch "global threed"
     puts $ch "array set threed \{ [array get threed] \}"
