@@ -21,7 +21,6 @@ proc BoxDialog {varname} {
     set var(dcoord) [lindex $rr 0]
     set var(dformat) $pmarker(dformat)
     AdjustCoordSystem $varname dcoord
-    set var(fill) [$var(frame) get marker $var(id) box fill]
 
     # procs
     set var(proc,apply) BoxApply
@@ -31,11 +30,6 @@ proc BoxDialog {varname} {
     # base
     MarkerBaseCenterDialog $varname
 
-    # menu
-    $var(mb).width add separator
-    $var(mb).width add checkbutton -label [msgcat::mc {Fill}] \
-	-variable ${varname}(fill) -command [list BoxFill $varname]
-
     # analysis
     $var(mb) add cascade -label [msgcat::mc {Analysis}] -menu $var(mb).analysis
     ThemeMenu $var(mb).analysis
@@ -98,15 +92,6 @@ proc BoxApply {varname} {
     MarkerBaseCenterApply $varname
 }
 
-# support
-
-proc BoxFill {varname} {
-    upvar #0 $varname var
-    global $varname
-
-    $var(frame) marker $var(id) box fill $var(fill)
-}
-
 # callbacks
 
 proc BoxCoordCB {varname {dummy {}}} {
