@@ -22,6 +22,7 @@ proc ButtonsDef {} {
     ButtonsColorDef
     ButtonsRegionDef
     ButtonsWCSDef
+    ButtonsIllustrateDef
     ButtonsAnalysisDef
     ButtonsHelpDef
 }
@@ -47,6 +48,7 @@ proc CreateButtons {} {
     CreateButtonsColor
     CreateButtonsRegion
     CreateButtonsWCS
+    CreateButtonsIllustrate
     CreateButtonsAnalysis
     CreateButtonsHelp
 
@@ -63,40 +65,43 @@ proc CreateButtonsMajor {} {
     ttk::frame $ds9(buttons).major
     RadioButton $ds9(buttons).major.file \
 	[string tolower [msgcat::mc {File}]] \
-	buttons(major,current) $ds9(buttons).file MajorButton
+	buttons major,current $ds9(buttons).file MajorButton
     RadioButton $ds9(buttons).major.edit \
 	[string tolower [msgcat::mc {Edit}]] \
-	buttons(major,current) $ds9(buttons).edit MajorButton
+	buttons major,current $ds9(buttons).edit MajorButton
     RadioButton $ds9(buttons).major.view \
 	[string tolower [msgcat::mc {View}]] \
-	buttons(major,current) $ds9(buttons).view MajorButton
+	buttons major,current $ds9(buttons).view MajorButton
     RadioButton $ds9(buttons).major.frame \
 	[string tolower [msgcat::mc {Frame}]] \
-	buttons(major,current) $ds9(buttons).frame MajorButton
+	buttons major,current $ds9(buttons).frame MajorButton
     RadioButton $ds9(buttons).major.bin \
 	[string tolower [msgcat::mc {Bin}]] \
-	buttons(major,current) $ds9(buttons).bin MajorButton
+	buttons major,current $ds9(buttons).bin MajorButton
     RadioButton $ds9(buttons).major.zoom \
 	[string tolower [msgcat::mc {Zoom}]] \
-	buttons(major,current) $ds9(buttons).zoom MajorButton
+	buttons major,current $ds9(buttons).zoom MajorButton
     RadioButton $ds9(buttons).major.scale \
 	[string tolower [msgcat::mc {Scale}]] \
-	buttons(major,current) $ds9(buttons).scale MajorButton
+	buttons major,current $ds9(buttons).scale MajorButton
     RadioButton $ds9(buttons).major.color \
 	[string tolower [msgcat::mc {Color}]] \
-	buttons(major,current) $ds9(buttons).color MajorButton
+	buttons major,current $ds9(buttons).color MajorButton
     RadioButton $ds9(buttons).major.region \
 	[string tolower [msgcat::mc {Region}]] \
-	buttons(major,current) $ds9(buttons).region MajorButton
+	buttons major,current $ds9(buttons).region MajorButton
     RadioButton $ds9(buttons).major.wcs \
 	[string tolower [msgcat::mc {WCS}]] \
-	buttons(major,current) $ds9(buttons).wcs MajorButton
+	buttons major,current $ds9(buttons).wcs MajorButton
+    RadioButton $ds9(buttons).major.illustrate \
+	[string tolower [msgcat::mc {Illustrate}]] \
+	buttons major,current $ds9(buttons).illustrate MajorButton
     RadioButton $ds9(buttons).major.analysis \
 	[string tolower [msgcat::mc {Analysis}]] \
-	buttons(major,current) $ds9(buttons).analysis MajorButton
+	buttons major,current $ds9(buttons).analysis MajorButton
     RadioButton $ds9(buttons).major.help \
 	[string tolower [msgcat::mc {Help}]] \
-	buttons(major,current) $ds9(buttons).help MajorButton
+	buttons major,current $ds9(buttons).help MajorButton
 
     global pbuttons
     array set pbuttons {
@@ -110,6 +115,7 @@ proc CreateButtonsMajor {} {
 	major,color 1
 	major,region 1
 	major,wcs 1
+	major,illustrate 1
 	major,analysis 1
 	major,help 1
     }
@@ -125,6 +131,7 @@ proc CreateButtonsMajor {} {
         $ds9(buttons).major.color pbuttons(major,color)
         $ds9(buttons).major.region pbuttons(major,region)
         $ds9(buttons).major.wcs pbuttons(major,wcs)
+        $ds9(buttons).major.illustrate pbuttons(major,illustrate)
         $ds9(buttons).major.analysis pbuttons(major,analysis)
         $ds9(buttons).major.help pbuttons(major,help)
     "
@@ -184,48 +191,32 @@ proc ButtonButton {button text cmd} {
 	-takefocus 0
 }
 
-proc RadioButton {button text varname value cmd} {
-    ttk::button $button \
-	-class TButtonBar \
-	-text $text \
-	-width -1 \
-	-takefocus 0 \
-	-command "RadioButtonSim $button $varname \{$value\} \{$cmd\}"
+# Radio Button
 
-    # setup trace on $varname, so that all buttons that use this variable
-    # will be updated when the variable is changed
-    uplevel #0 trace variable $varname w \
-	[list "RadioButtonCB $button \{$value\}"]
-
-    # setup <Map> event so that anytime the button is redrawn,
-    # it is updated
-    bind $button <Map> "ButtonMap %W $varname"
-}
-
-proc CheckButton {button text varname cmd} {
-    ttk::button $button \
-	-class TButtonBar \
-	-text $text \
-	-width -1 \
-	-takefocus 0 \
-	-command "CheckButtonSim $button $varname \{$cmd\}"
-
-    uplevel #0 trace variable $varname w [list "CheckButtonCB $button"]
-
-    bind $button <Map> "ButtonMap %W $varname"
-}
-
-proc ButtonMap {button varname} {
+proc RadioButton {button text varname id value cmd} {
     upvar #0 $varname var
-    set vv $var
+    global $varname
 
-    # delay slightly, I don't know why this is needed
-    after 10 [list set $varname $vv]
+    ttk::button $button \
+	-class TButtonBar \
+	-text $text \
+	-width -1 \
+	-takefocus 0 \
+	-command [list RadioButtonCmd $varname $id $value $cmd]
+
+    trace add variable ${varname}($id) write [list RadioButtonCB $button $value]
+    # set the proper state
+    RadioButtonCB $button $value $varname $id write
 }
 
-proc RadioButtonSim {button varname value cmd} {
-    uplevel #0 [list set $varname $value]
-    eval $cmd
+proc RadioButtonCmd {varname id value cmd} {
+    upvar #0 $varname var
+    global $varname
+
+    set ${varname}($id) $value
+    if {$cmd != {}} {
+	eval $cmd
+    }
 }
 
 proc RadioButtonCB {button value varname id op} {
@@ -255,14 +246,34 @@ proc RadioButtonCB {button value varname id op} {
     }
 }
 
-proc CheckButtonSim {button varname cmd} {
+# Check Button
+
+proc CheckButton {button text varname id cmd} {
+    global $varname
+    
+    ttk::button $button \
+	-class TButtonBar \
+	-text $text \
+	-width -1 \
+	-takefocus 0 \
+	-command [list CheckButtonCmd $varname $id $cmd]
+
+    trace add variable ${varname}($id) write [list CheckButtonCB $button]
+    # set the proper state
+    CheckButtonCB $button $varname $id write
+}
+
+proc CheckButtonCmd {varname id cmd} {
     upvar #0 $varname var
-    uplevel #0 [list set $varname [expr !$var]]
-    eval $cmd
+    global $varname
+
+    set ${varname}($id) [expr !$var($id)]
+    if {$cmd != {}} {
+	eval $cmd
+    }
 }
 
 proc CheckButtonCB {button varname id op} {
-    upvar #0 $varname var
     global $varname
 
     global ds9
@@ -270,7 +281,7 @@ proc CheckButtonCB {button varname id op} {
     if {[$button cget -state] != {disabled}} {
 	switch $ds9(wm) {
 	    x11 {
-		if {$var($id)} {
+		if {[set ${varname}($id)]} {
 		    $button configure -state active
 		} else {
 		    $button configure -state normal
@@ -278,7 +289,7 @@ proc CheckButtonCB {button varname id op} {
 	    }
 	    aqua -
 	    win32 {
-		if {$var($id)} {
+		if {[set ${varname}($id)]} {
 		    $button configure -default active
 		} else {
 		    $button configure -default normal
@@ -326,6 +337,21 @@ proc LayoutButtons {} {
 		pack $ds9(buttons,aux) -side left -fill both -expand true
 	    }
 
+	    pack $ds9(buttons).major -side top -fill x -expand true -anchor n
+	}
+	basic {}
+	advanced {
+	    pack propagate $ds9(buttons) off
+	    $ds9(buttons) configure -width 100
+	    pack $ds9(buttons) -side left -fill both -expand true
+
+	    if {$ianalysis(buttonbar,count)>0} {
+		$ds9(buttons,aux) configure \
+		    -width [expr 100*$ianalysis(buttonbar,count)]
+		pack propagate $ds9(buttons,aux) off
+		pack $ds9(buttons,aux) -side left -fill both -expand true
+	    }
+
 	    pack $ds9(buttons).major -side top -fill x -expand true -anchor n
 	}
     }
@@ -341,6 +367,7 @@ proc LayoutButtons {} {
     UpdateButtons buttons(color)
     UpdateButtons buttons(region)
     UpdateButtons buttons(wcs)
+    UpdateButtons buttons(illustrate)
     UpdateButtons buttons(analysis)
     UpdateButtons buttons(help)
 
@@ -355,6 +382,14 @@ proc LayoutButtons {} {
 proc MajorButton {} {
     global buttons
     global view
+    global ds9
+
+    # kludge: Aqua has a bug, avoid multiple <Configure> events
+    switch $ds9(wm) {
+	x11 {}
+	aqua {bind $ds9(canvas) <Configure> {}}
+	win32 {}
+    }
 
     pack forget $buttons(major,prev)
     switch $view(layout) {
@@ -364,8 +399,18 @@ proc MajorButton {} {
 	vertical {
 	    pack $buttons(major,current) -side bottom -fill x -expand true -anchor s
 	}
+	basic {}
+	advanced {
+	    pack $buttons(major,current) -side bottom -fill x -expand true -anchor s
+	}
     }
     set buttons(major,prev) $buttons(major,current)
+
+    switch $ds9(wm) {
+	x11 {}
+	aqua {bind $ds9(canvas) <Configure> [list LayoutView]}
+	win32 {}
+    }
 }
 
 proc AnalysisButton {} {
@@ -382,6 +427,10 @@ proc AnalysisButton {} {
 	    vertical {
 		pack $ds9(buttons,aux,$ii) -side left -fill x -expand true -anchor n
 	    }
+	    basic {}
+	    advanced {
+		pack $ds9(buttons,aux,$ii) -side left -fill x -expand true -anchor n
+	    }
 	}
     }
 }
@@ -405,6 +454,18 @@ proc ShowButton {which varname} {
  	switch $view(layout) {
 	    horizontal {pack $which -side left -fill both -expand true}
 	    vertical {pack $which -side top -fill both -expand true}
+	    basic {}
+	    advanced {pack $which -side top -fill both -expand true}
  	}
     }
 }
+
+proc ConfigureButtons {menu state} {
+    global ds9
+    global pbuttons
+
+    foreach aa [array names pbuttons "$menu,*"] {
+	set bb [lindex [split $aa {,}] 1]
+	$ds9(buttons).$menu.$bb configure -state $state
+    }
+}
