@@ -1,4 +1,4 @@
-#  Copyright (C) 1999-2018
+#  Copyright (C) 1999-2021
 #  Smithsonian Astrophysical Observatory, Cambridge, MA, USA
 #  For conditions of distribution and use, see copyright notice in "copyright"
 
@@ -361,17 +361,15 @@ proc CATMatchAnd1and2 {varname1 varname2 rrname} {
     set var(radius) {}
 
     # required 
+    set T(Nrows) 0
     set T(Header) $T1(Header)
     foreach ll $T2(Header) {
 	# make cols unique
 	lappend T(Header) "2_$ll"
     }
-    set T(Dashes) [regsub -all {[A-Za-z0-9]} $T(Header) {-}]
-    set T(Ndshs) [expr $T1(Ndshs)+$T2(Ndshs)]
-    set T(H_1) $T(Header)
-    set T(H_2) $T(Dashes)
     set T(HLines) 2
-    set T(Nrows) 0
+    set T(H_1) $T(Header)
+    set T(H_2) [regsub -all {[A-Za-z0-9]} $T(Header) {-}]
     starbase_colmap T
 
     # optional
@@ -444,7 +442,7 @@ proc CATMatchAnd1and2 {varname1 varname2 rrname} {
 	incr T(Nrows)
     }
 
-    ARDone $varname
+    ARStatus $varname [msgcat::mc {Done}]
     CATLoadDone $varname
 }
 
@@ -482,14 +480,12 @@ proc CATMatchAnd1only {varname1 varname2 rrname} {
     set var(radius) {}
 
    # required 
+    set T(Nrows) 0
     set T(Header) $T1(Header)
-    set T(Dashes) $T1(Dashes)
-    set T(Ndshs) $T1(Ndshs)
     set T(HLines) $T1(HLines)
     for {set ii 1} {$ii<=$T1(HLines)} {incr ii} {
 	set T(H_$ii) $T1(H_$ii)
     }
-    set T(Nrows) 0
     starbase_colmap T
 
     # optional
@@ -532,7 +528,7 @@ proc CATMatchAnd1only {varname1 varname2 rrname} {
 	incr T(Nrows)
     }
 
-    ARDone $varname
+    ARStatus $varname [msgcat::mc {Done}]
     CATLoadDone $varname
 }
 
@@ -570,14 +566,12 @@ proc CATMatchAnd2only {varname1 varname2 rrname} {
     set var(radius) {}
 
    # required 
+    set T(Nrows) 0
     set T(Header) $T2(Header)
-    set T(Dashes) $T2(Dashes)
-    set T(Ndshs) $T2(Ndshs)
     set T(HLines) $T2(HLines)
     for {set ii 1} {$ii<=$T2(HLines)} {incr ii} {
 	set T(H_$ii) $T2(H_$ii)
     }
-    set T(Nrows) 0
     starbase_colmap T
 
     # optional
@@ -620,7 +614,7 @@ proc CATMatchAnd2only {varname1 varname2 rrname} {
 	incr T(Nrows)
     }
 
-    ARDone $varname
+    ARStatus $varname [msgcat::mc {Done}]
     CATLoadDone $varname
 }
 
@@ -658,14 +652,12 @@ proc CATMatchNot {varname1 varname2 rrname} {
     set var(radius) {}
 
     # required 
+    set T(Nrows) 0
     set T(Header) $T1(Header)
-    set T(Dashes) $T1(Dashes)
-    set T(Ndshs) $T1(Ndshs)
     set T(HLines) $T1(HLines)
     for {set ii 1} {$ii<=$T1(HLines)} {incr ii} {
 	set T(H_$ii) $T1(H_$ii)
     }
-    set T(Nrows) 0
     starbase_colmap T
 
     # optional
@@ -714,6 +706,6 @@ proc CATMatchNot {varname1 varname2 rrname} {
 	}
     }
 
-    ARDone $varname
+    ARStatus $varname [msgcat::mc {Done}]
     CATLoadDone $varname
 }
