@@ -69,6 +69,17 @@ proc CommSet {fn paramlist {safemode 0}} {
 	    grid {ProcessGridCmd param i}
 	    header {ProcessHeaderCmd param i}
 	    height {ProcessHeightCmd param i}
+
+	    hls {ProcessHLSCmd param i}
+	    hlsarray {ProcessHLSArrayCmd param i {} $fn}
+	    hlscube {ProcessHLSCubeCmd param i {} $fn}
+	    hlsimage {ProcessHLSImageCmd param i {} $fn}
+
+	    hsv {ProcessHSVCmd param i}
+	    hsvarray {ProcessHSVArrayCmd param i {} $fn}
+	    hsvcube {ProcessHSVCubeCmd param i {} $fn}
+	    hsvimage {ProcessHSVImageCmd param i {} $fn}
+
 	    iconify {ProcessIconifyCmd param i}
 	    iexam -
 	    imexam {}
@@ -148,10 +159,12 @@ proc CommSet {fn paramlist {safemode 0}} {
 	    restore {ProcessRestoreCmd param i}
 	    region -
 	    regions {ProcessRegionsCmd param i {} $fn}
+
 	    rgb {ProcessRGBCmd param i}
 	    rgbarray {ProcessRGBArrayCmd param i {} $fn}
 	    rgbcube {ProcessRGBCubeCmd param i {} $fn}
 	    rgbimage {ProcessRGBImageCmd param i {} $fn}
+
 	    rotate {ProcessRotateCmd param i}
 	    samp {ProcessSAMPCmd param i}
 	    save -
@@ -264,7 +277,7 @@ proc CommGet {proc id paramlist fn} {
 	    cd {ProcessSendCDCmd $proc $id $param}
 	    cmap {ProcessSendCmapCmd $proc $id $param}
 	    colorbar {ProcessSendColorbarCmd $proc $id $param}
-	    console {}
+	    console {ProcessSendNullCmd $proc $id $cmd}
 	    contours -
 	    contour {
 		ProcessSendContourCmd $proc $id $param {} $fn.ctr
@@ -272,7 +285,7 @@ proc CommGet {proc id paramlist fn} {
 	    }
 	    crop {ProcessSendCropCmd $proc $id $param}
 	    crosshair {ProcessSendCrosshairCmd $proc $id $param}
-	    cursor {}
+	    cursor {ProcessSendNullCmd $proc $id $cmd}
 	    data {
 		ProcessSendDataCmd $proc $id $param {} $fn.dat
 		return $fn.data
@@ -283,9 +296,9 @@ proc CommGet {proc id paramlist fn} {
 	    dsssao {ProcessSendSAOCmd $proc $id $param}
 	    dsseso {ProcessSendESOCmd $proc $id $param}
 	    dssstsci {ProcessSendSTSCICmd $proc $id $param}
-	    envi {}
-	    exit {}
-	    export {}
+	    envi {ProcessSendNullCmd $proc $id $cmd}
+	    exit {ProcessSendNullCmd $proc $id $cmd}
+	    export {ProcessSendNullCmd $proc $id $cmd}
 	    fade {ProcessSendFadeCmd $proc $id $param}
 	    file {ProcessSendFileCmd $proc $id $param}
 	    fits {
@@ -301,8 +314,37 @@ proc CommGet {proc id paramlist fn} {
 	    }
 	    graph {ProcessSendGraphCmd $proc $id $param}
 	    grid {ProcessSendGridCmd $proc $id $param}
-	    header {}
+	    header {ProcessSendNullCmd $proc $id $cmd}
 	    height {ProcessSendHeightCmd $proc $id $param}
+
+	    hls {ProcessSendHLSCmd $proc $id $param}
+	    hlsarray {
+		ProcessSendHLSArrayCmd $proc $id $param {} $fn.fits
+		return $fn.fits
+	    }
+	    hlscube {
+		ProcessSendHLSCubeCmd $proc $id $param {} $fn.fits
+		return $fn.fits
+	    }
+	    hlsimage {
+		ProcessSendHLSImageCmd $proc $id $param {} $fn.fits
+		return $fn.fits
+	    }
+
+	    hsv {ProcessSendHSVCmd $proc $id $param}
+	    hsvarray {
+		ProcessSendHSVArrayCmd $proc $id $param {} $fn.fits
+		return $fn.fits
+	    }
+	    hsvcube {
+		ProcessSendHSVCubeCmd $proc $id $param {} $fn.fits
+		return $fn.fits
+	    }
+	    hsvimage {
+		ProcessSendHSVImageCmd $proc $id $param {} $fn.fits
+		return $fn.fits
+	    }
+
 	    iconify {ProcessSendIconifyCmd $proc $id $param}
 	    iexam -
 	    imexam {ProcessSendIExamCmd $proc $id $param}
@@ -314,10 +356,10 @@ proc CommGet {proc id paramlist fn} {
 		return $fn.jpg
 	    }
 	    lock {ProcessSendLockCmd $proc $id $param}
-	    lower {}
+	    lower {ProcessSendNullCmd $proc $id $cmd}
 	    magnifier {ProcessSendMagnifierCmd $proc $id $param}
 	    mask {ProcessSendMaskCmd $proc $id $param}
-	    match {}
+	    match {ProcessSendNullCmd $proc $id $cmd}
 	    mecube {
 		ProcessSendMECubeCmd $proc $id $param {} $fn.fits
 		return $fn.fits
@@ -352,9 +394,9 @@ proc CommGet {proc id paramlist fn} {
 		# backward compatibility
 	    }
 	    savempeg -
-	    movie {}
+	    movie {ProcessSendNullCmd $proc $id $cmd}
 	    memf -
-	    multiframe {}
+	    multiframe {ProcessSendNullCmd $proc $id $cmd}
 	    nameserver {ProcessSendNRESCmd $proc $id $param}
 	    nan {
 		# backward compatibility prefs
@@ -391,13 +433,14 @@ proc CommGet {proc id paramlist fn} {
 	    psprint {ProcessSendPrintCmd $proc $id $param}
 	    prism {ProcessSendPrismCmd $proc $id $param}
 	    exit -
-	    quit {}
-	    raise {}
+	    quit {ProcessSendNullCmd $proc $id $cmd}
+	    raise {ProcessSendNullCmd $proc $id $cmd}
 	    region -
 	    regions {
 		ProcessSendRegionsCmd $proc $id $param {} $fn.reg
 		return $fn.reg
 	    }
+
 	    rgb {ProcessSendRGBCmd $proc $id $param}
 	    rgbarray {
 		ProcessSendRGBArrayCmd $proc $id $param {} $fn.fits
@@ -411,11 +454,12 @@ proc CommGet {proc id paramlist fn} {
 		ProcessSendRGBImageCmd $proc $id $param {} $fn.fits
 		return $fn.fits
 	    }
+
 	    rotate {ProcessSendRotateCmd $proc $id $param}
 	    samp {ProcessSendSAMPCmd $proc $id $param}
 	    save -
-	    savefits {}
-	    saveimage {}
+	    savefits {ProcessSendNullCmd $proc $id $cmd}
+	    saveimage {ProcessSendNullCmd $proc $id $cmd}
 	    scale {ProcessSendScaleCmd $proc $id $param}
 	    sfits {
 		# backward compatibility
@@ -434,9 +478,9 @@ proc CommGet {proc id paramlist fn} {
 		# backward compatibility
 	    }
 	    smooth {ProcessSendSmoothCmd $proc $id $param}
-	    source {}
-	    srgbcube {}
-	    tcl {}
+	    source {ProcessSendNullCmd $proc $id $cmd}
+	    srgbcube {ProcessSendNullCmd $proc $id $cmd}
+	    tcl {ProcessSendNullCmd $proc $id $cmd}
 	    theme {
 		# backward compatibility prefs
 		ProcessSendThemeCmd $proc $id $param
@@ -448,11 +492,11 @@ proc CommGet {proc id paramlist fn} {
 	    tif -
 	    tiff {
 		ProcessSendTIFFCmd $proc $id $param {} $fn.tif
-		$fn.tif
+		return $fn.tif
 	    }
 	    tile {ProcessSendTileCmd $proc $id $param}
-	    update {}
-	    url {}
+	    update {ProcessSendNullCmd $proc $id $cmd}
+	    url {ProcessSendNullCmd $proc $id $cmd}
 	    version {ProcessSendVersionCmd $proc $id $param}
 	    view {ProcessSendViewCmd $proc $id $param}
 	    vla -
@@ -465,12 +509,10 @@ proc CommGet {proc id paramlist fn} {
 	    xpa {ProcessSendXPACmd $proc $id $param}
 	    zscale {ProcessSendZScaleCmd $proc $id $param}
 	    zoom {ProcessSendZoomCmd $proc $id $param}
-	    default {
-		Error "[msgcat::mc {Unknown command}]: $cmd"
-		$proc $id {}
-	    }
+	    default {ProcessSendNullCmd $proc $id $cmd}
 	}
     }
+
     # default, no filename
     return {}
 }
