@@ -4,13 +4,6 @@
 
 package provide DS9 1.0
 
-proc BadVisualError {} {
-    global ds9
-
-    Error [msgcat::mc {Sorry, DS9 requires a Truecolor8, Truecolor16, Truecolor24 visual be available}]
-    exit
-}
-
 proc ProcessCommandLineFirst {} {
     global argc
     global argv
@@ -134,6 +127,7 @@ proc ProcessCommand {argv argc} {
 	    -2mass {incr i; Process2MASSCmd argv i}
 	    -3d -
 	    -3D {incr i; Process3DCmd argv i}
+
 	    -about {ProcessSendAboutCmd puts stdout {} {} {}}
 	    -align {incr i; ProcessAlignCmd argv i}
 	    -analysis {incr i; ProcessAnalysisCmd argv i {} {}}
@@ -145,6 +139,7 @@ proc ProcessCommand {argv argc} {
 		set view(layout) advanced
 		LayoutView
 	    }
+
 	    -bg -
 	    -background {
 		# backward compatibility prefs
@@ -161,6 +156,7 @@ proc ProcessCommand {argv argc} {
 	    -block {incr i; ProcessBlockCmd argv i}
 	    -blink {incr i; ProcessBlinkCmd argv i}
 	    -blue {set current(rgb) blue; RGBChannel}
+
 	    -cat -
 	    -catalog {incr i; ProcessCatalogCmd argv i}
 	    -cd {incr i; ProcessCDCmd argv i}
@@ -173,6 +169,7 @@ proc ProcessCommand {argv argc} {
 	    -crop {incr i; ProcessCropCmd argv i}
 	    -crosshair {incr i; ProcessCrosshairCmd argv i}
 	    -cursor {incr i; ProcessCursorCmd argv i}
+
 	    -datacube -
 	    -cube {incr i; ProcessCubeCmd argv i}
 	    -debug {incr i; ProcessDebugCmd argv i}
@@ -180,10 +177,12 @@ proc ProcessCommand {argv argc} {
 	    -dsssao {incr i; ProcessSAOCmd argv i}
 	    -dsseso {incr i; ProcessESOCmd argv i}
 	    -dssstsci {incr i; ProcessSTSCICmd argv i}
+	    
 	    -envi {set file(type) envi}
 	    -export {incr i; ProcessExportCmd argv i}
 	    -exit -
 	    -quit {ProcessQuitCmd argv i}
+
 	    -fade {incr i; ProcessFadeCmd argv i}
 	    -frame {incr i; ProcessFrameCmd argv i}
 	    -fifo {
@@ -205,6 +204,7 @@ proc ProcessCommand {argv argc} {
 	    -fits {set file(type) fits; CommandFitsCmd argv i}
 	    -fp -
 	    -footprint {incr i; ProcessFootprintCmd argv i}
+
 	    -geometry {
 		# already processed
 	    }
@@ -212,10 +212,12 @@ proc ProcessCommand {argv argc} {
 	    -green {set current(rgb) green; RGBChannel}
 	    -graph {incr i; ProcessGraphCmd argv i}
 	    -grid {incr i; ProcessGridCmd argv i}
-	    -nogrid {set grid(view) 0; GridUpdateCurrent}
+	    -nogrid {set grid(view) 0; UpdateGridCurrent}
+
 	    -header {incr i; ProcessHeaderCmd argv i}
 	    -height {incr i; ProcessHeightCmd argv i}
 	    -histequ {set scale(type) histequ; ChangeScale}
+
 	    -horizontal {
 		#backward compatibility
 		set view(layout) horizontal
@@ -231,6 +233,23 @@ proc ProcessCommand {argv argc} {
 		set view(graph,horz) 0
 		LayoutView
 	    }
+	    -hls {incr i; ProcessHLSCmd argv i}
+	    -hlsarray {set file(type) hlsarray}
+	    -hlscube {set file(type) hlscube}
+	    -hlsimage {set file(type) hlsimage}
+
+	    -hsv {incr i; ProcessHSVCmd argv i}
+	    -hsvarray {set file(type) hsvarray}
+	    -hsvcube {set file(type) hsvcube}
+	    -hsvimage {set file(type) hsvimage}
+
+	    -hue {
+		set current(hsv) hue
+		HSVChannel
+		set current(hls) hue
+		HLSChannel
+	    }
+
 	    -iconify {incr i; ProcessIconifyCmd argv i}
 	    -iis {incr i; ProcessIISCmd argv i}
 	    -illustrate {incr i; ProcessIllustrateCmd argv i {} {}}
@@ -245,16 +264,20 @@ proc ProcessCommand {argv argc} {
 		LayoutView
 	    }
 	    -invert {set colorbar(invert) 1; InvertColorbar}
+
 	    -jpg -
 	    -jpeg {set file(type) jpeg}
+
 	    -language {
 		# already processed
 		incr i
 	    }
+	    -lightness {set current(hls) lightness; HLSChannel}	    
 	    -lock {incr i; ProcessLockCmd argv i}
 	    -linear {set scale(type) linear; ChangeScale}
 	    -log {set scale(type) log; ChangeScale}
 	    -lower {ProcessLowerCmd argv i}
+
 	    -magnifier {incr i; ProcessMagnifierCmd argv i}
 	    -nomagnifier {
 		# backward compatibility
@@ -279,7 +302,6 @@ proc ProcessCommand {argv argc} {
 		set minmax(sample) [lindex $argv $i]
 	    }
 	    -mode {incr i; ProcessModeCmd argv i}
-
 	    -mosaic {
 		set file(type) mosaic
 		CommandMosaicCmd argv i
@@ -288,7 +310,6 @@ proc ProcessCommand {argv argc} {
 		set file(type) mosaicimage
 		CommandMosaicImageCmd argv i
 	    }
-
 	    -mosaicimageiraf {
 		# backward compatibility
 		set file(type) mosaicimage
@@ -304,7 +325,6 @@ proc ProcessCommand {argv argc} {
 		set file(type) mosaicimage
 		set file(mosaic) wfpc2
 	    }
-
 	    -mosaiciraf {
 		# backward compatibility
 		set file(type) mosaic
@@ -317,11 +337,11 @@ proc ProcessCommand {argv argc} {
 	    }
 	    -savempeg -
 	    -movie {incr i; ProcessMovieCmd argv i}
-
 	    -msg {
 		# already processed
 		incr i
 	    }
+
 	    -nameserver {incr i; ProcessNRESCmd argv i}
 	    -nan {
 		# backward compatibility prefs
@@ -332,7 +352,9 @@ proc ProcessCommand {argv argc} {
 	    -notes {incr i; ProcessNotesCmd argv i}
 	    -nrrd {set file(type) nrrd}
 	    -nvss {incr i; ProcessNVSSCmd argv i}
+
 	    -orient {incr i; ProcessOrientCmd argv i}
+
 	    -pagesetup {incr i; ProcessPageSetupCmd argv i}
 	    -pspagesetup {incr i; ProcessPSPageSetupCmd argv i}
 	    -pan {incr i; ProcessPanCmd argv i}
@@ -375,25 +397,36 @@ proc ProcessCommand {argv argc} {
 	    -private {
 		#already processed
 	    }
+
 	    -raise {ProcessRaiseCmd argv i}
 	    -red {set current(rgb) red; RGBChannel}
 	    -region -
 	    -regions -
 	    -regionfile {incr i; ProcessRegionsCmd argv i {} {}}
 	    -restore {incr i; ProcessRestoreCmd argv i}
+
 	    -rgb {incr i; ProcessRGBCmd argv i}
+	    -rgbarray {set file(type) rgbarray}
+	    -rgbimage {set file(type) rgbimage}
 	    -rgbcube {set file(type) rgbcube}
 	    -srgbcube {
 		# backward compatibility
 		set file(type) srgbcube
 	    }
-	    -rgbimage {set file(type) rgbimage}
-	    -rgbarray {set file(type) rgbarray}
+
 	    -rotate {incr i; ProcessRotateCmd argv i}
 	    -samp {incr i; ProcessSAMPCmd argv i}
 	    -savefits -
 	    -save {incr i; ProcessSaveCmd argv i}
 	    -saveimage {incr i; ProcessSaveImageCmd argv i}
+
+	    -sat -
+	    -saturation {
+		set current(hsv) saturation
+		HSVChannel
+		set current(hls) saturation
+		HLSChannel
+	    }
 	    -scale -
 	    -ztrans {incr i; ProcessScaleCmd argv i}
 	    -scalelims -
@@ -449,6 +482,7 @@ proc ProcessCommand {argv argc} {
 	    -squared {set scale(type) squared; ChangeScale}
 	    -sqrt {set scale(type) sqrt; ChangeScale}
 	    -source {incr i; ProcessSourceCmd argv i}
+
 	    -tcl {incr i; ; ProcessTclCmd argv i {} {}}
 	    -theme {
 		# backward compatibility prefs
@@ -473,8 +507,11 @@ proc ProcessCommand {argv argc} {
 		set iis(ofifo) none
 		set iis(port) 0
 	    }
+
 	    -url {set file(type) url}
 	    -update {incr i; ProcessUpdateCmd argv i}
+
+	    -value {set current(hsv) value; HSVChannel}	    
 	    -vertical {
 		#backward compatibility
 		set view(layout) vertical
@@ -498,6 +535,7 @@ proc ProcessCommand {argv argc} {
 	    -first {incr i; ProcessVLACmd argv i}
 	    -vlss  {incr i; ProcessVLSSCmd argv i}
 	    -vo {incr i; ProcessVOCmd argv i}
+
 	    -wcs {incr i; ProcessWCSCmd argv i {} {}}
 	    -wcsformat {
 		#backward compatibility
@@ -506,7 +544,9 @@ proc ProcessCommand {argv argc} {
 	    }
 	    -web {incr i; ProcessWebCmd argv i}
 	    -width {incr i; ProcessWidthCmd argv i}
+
 	    -xpa {incr i; ProcessXPACmd argv i}
+
 	    -z1 {
 		#backward compatibility
 		incr i
@@ -569,6 +609,8 @@ proc CommandLineLoad {item argvname iname} {
 	switch -- [$current(frame) get type] {
 	    base {CommandLineLoadBase $item $argvname $iname}
 	    rgb {CommandLineLoadRGB $item $argvname $iname}
+	    hsv -
+	    hls {CommandLineLoadT $item $argvname $iname}
 	    3d {CommandLineLoad3D $item $argvname $iname}
 	}
     } else {
@@ -592,11 +634,7 @@ proc CommandLineLoadBase {item argvname iname} {
 	    MultiLoad $file(layer) $file(mode)
 	    LoadFitsFile $item $file(layer) $file(mode)
 	}
-	url {
-	    MultiLoad $file(layer) $file(mode)
-	    LoadURLFits $item $file(layer) $file(mode)
-	}
-
+	url {LoadURLFits $item $file(layer) $file(mode) 1}
 
 	rgbimage {
 	    MultiLoadRGB
@@ -607,6 +645,24 @@ proc CommandLineLoadBase {item argvname iname} {
 	    LoadRGBCubeFile $item
 	}
 
+	hlsimage {
+	    MultiLoadHLS
+	    LoadHLSImageFile $item
+	}
+	hlscube {
+	    MultiLoadHLS
+	    LoadHLSCubeFile $item
+	}
+
+	hsvimage {
+	    MultiLoadHSV
+	    LoadHSVImageFile $item
+	}
+	hsvcube {
+	    MultiLoadHSV
+	    LoadHSVCubeFile $item
+	}
+
 	mecube {
 	    MultiLoad
 	    LoadMECubeFile $item
@@ -656,10 +712,20 @@ proc CommandLineLoadBase {item argvname iname} {
 	    MultiLoad $file(layer)
 	    ImportArrayFile $item $file(layer)
 	}
+
 	rgbarray {
 	    MultiLoadRGB
 	    ImportRGBArrayFile $item
 	}
+	hlsarray {
+	    MultiLoadHLS
+	    ImportHLSArrayFile $item
+	}
+	hsvarray {
+	    MultiLoadHSV
+	    ImportHSVArrayFile $item
+	}
+
 	nrrd {
 	    MultiLoad $file(layer)
 	    ImportNRRDFile $item $file(layer)
@@ -690,10 +756,11 @@ proc CommandLineLoadRGB {item argvname iname} {
     upvar 2 $iname i
 
     global file
+    global current
 
     switch -- $file(type) {
 	fits {LoadFitsFile $item {} $file(mode)}
-	url {LoadURLFits $item {} $file(mode)}
+	url {LoadURLFits $item {} $file(mode) 0}
 
 	rgbimage {
 	    MultiLoadRGB
@@ -704,6 +771,24 @@ proc CommandLineLoadRGB {item argvname iname} {
 	    LoadRGBCubeFile $item
 	}
 
+	hlsimage {
+	    MultiLoadHLS
+	    LoadHLSImageFile $item
+	}
+	hlscube {
+	    MultiLoadHLS
+	    LoadHLSCubeFile $item
+	}
+
+	hsvimage {
+	    MultiLoadHSV
+	    LoadHSVImageFile $item
+	}
+	hsvcube {
+	    MultiLoadHSV
+	    LoadHSVCubeFile $item
+	}
+
 	mecube {LoadMECubeFile $item}
 	multiframe {
 	    # not supported
@@ -744,12 +829,23 @@ proc CommandLineLoadRGB {item argvname iname} {
 	}
 
 	array {ImportArrayFile $item {}}
+
 	rgbarray {
 	    MultiLoadRGB
 	    ImportRGBArrayFile $item
 	}
+	hlsarray {
+	    MultiLoadHLS
+	    ImportHLSArrayFile $item
+	}
+	hsvarray {
+	    MultiLoadHSV
+	    ImportHSVArrayFile $item
+	}
+
 	nrrd {ImportNRRDFile $item {}}
 	envi {}
+
 	gif -
 	tiff -
 	jpeg -
@@ -757,10 +853,110 @@ proc CommandLineLoadRGB {item argvname iname} {
 	    MultiLoadRGB
 	    ImportPhotoFile $item $file(mode)
 	}
-
     }
 }
 
+proc CommandLineLoadT {item argvname iname} {
+    upvar 2 $argvname argv
+    upvar 2 $iname i
+
+    global file
+    global current
+
+    switch -- $file(type) {
+	fits {LoadFitsFile $item {} $file(mode)}
+	url {LoadURLFits $item {} $file(mode) 0}
+
+	rgbimage {
+	    MultiLoadRGB
+	    LoadRGBImageFile $item
+	}
+	rgbcube {
+	    MultiLoadRGB
+	    LoadRGBCubeFile $item
+	}
+
+	hlsimage {
+	    MultiLoadHLS
+	    LoadHLSImageFile $item
+	}
+	hlscube {
+	    MultiLoadHLS
+	    LoadHLSCubeFile $item
+	}
+
+	hsvimage {
+	    MultiLoadHSV
+	    LoadHSVImageFile $item
+	}
+	hsvcube {
+	    MultiLoadHSV
+	    LoadHSVCubeFile $item
+	}
+
+	mecube {LoadMECubeFile $item}
+	multiframe {
+	    # not supported
+	}
+
+	mosaicimage {
+	    switch -- $file(mosaic) {
+		iraf {LoadMosaicImageIRAFFile $item {}}
+		wfpc2 {LoadMosaicImageWFPC2File $item {}}
+		default {LoadMosaicImageWCSFile $item {} $file(mosaic)}
+	    }
+	}
+	mosaic {
+	    switch -- $file(mosaic) {
+		iraf {LoadMosaicIRAFFile $item {}}
+		default {LoadMosaicWCSFile $item {} $file(mosaic)}
+	    }
+	}
+
+	sfits {
+	    #backward compatibility
+	    incr i
+	    LoadSFitsFile $item [lindex $argv $i] {} $file(mode)
+	}
+	srgbcube {
+	    #backward compatibility
+	    MultiLoadRGB
+	    incr i
+	    LoadSRGBCubeFile $item [lindex $argv $i]
+	}
+	smosaic {
+	    #backward compatibility
+	    incr i
+	    switch -- $file(mosaic) {
+		iraf {LoadMosaicIRAFSFitsFile $item [lindex $argv $i] {}}
+		default {LoadMosaicWCSSFitsFile $item [lindex $argv $i] {} $file(mosaic)}
+	    }
+	}
+
+	array {ImportArrayFile $item {}}
+
+	rgbarray {
+	    MultiLoadRGB
+	    ImportRGBArrayFile $item
+	}
+	hlsarray {
+	    MultiLoadHLS
+	    ImportHLSArrayFile $item
+	}
+	hsvarray {
+	    MultiLoadHSV
+	    ImportHSVArrayFile $item
+	}
+
+	nrrd {ImportNRRDFile $item {}}
+	envi {}
+
+	gif -
+	tiff -
+	jpeg -
+	png {}
+    }
+}
 proc CommandLineLoad3D {item argvname iname} {
     upvar 2 $argvname argv
     upvar 2 $iname i
@@ -772,10 +968,7 @@ proc CommandLineLoad3D {item argvname iname} {
 	    MultiLoad {} $file(mode)
 	    LoadFitsFile $item {} $file(mode)
 	}
-	url {
-	    MultiLoad {} $file(mode)
-	    LoadURLFits $item {} $file(mode)
-	}
+	url {LoadURLFits $item {} $file(mode) 1}
 
 	rgbimage {
 	    MultiLoadRGB
@@ -786,6 +979,24 @@ proc CommandLineLoad3D {item argvname iname} {
 	    LoadRGBCubeFile $item
 	}
 
+	hlsimage {
+	    MultiLoadHLS
+	    LoadHLSImageFile $item
+	}
+	hlscube {
+	    MultiLoadHLS
+	    LoadHLSCubeFile $item
+	}
+
+	hsvimage {
+	    MultiLoadHSV
+	    LoadHSVImageFile $item
+	}
+	hsvcube {
+	    MultiLoadHSV
+	    LoadHSVCubeFile $item
+	}
+
 	mecube {
 	    MultiLoad
 	    LoadMECubeFile $item
@@ -835,10 +1046,20 @@ proc CommandLineLoad3D {item argvname iname} {
 	    MultiLoad
 	    ImportArrayFile $item {}
 	}
+
 	rgbarray {
 	    MultiLoadRGB
 	    ImportRGBArrayFile $item
 	}
+	hlsarray {
+	    MultiLoadHLS
+	    ImportHLSArrayFile $item
+	}
+	hsvarray {
+	    MultiLoadHSV
+	    ImportHSVArrayFile $item
+	}
+
 	nrrd {
 	    MultiLoad
 	    ImportNRRDFile $item {}
@@ -882,10 +1103,17 @@ proc CommandFitsCmd {varname iname} {
 		default {CommandMosaicType $item $iname}
 	    }
 	}
+
 	mecube -
 	multiframe -
+
 	rgbcube -
-	rgbimage {
+	hlscube -
+	hsvcube -
+
+	rgbimage -
+	hlsimage -
+	hlsimage {
 	    set file(type) $item
 	    incr i
 	}
