@@ -431,7 +431,7 @@ proc ContourCPasteDialog {} {
     global ds9
     global current
     global contour
-    global ed
+    global ed2
 
     if {$current(frame) == {} || $contour(copy) == {}} {
 	return
@@ -439,40 +439,40 @@ proc ContourCPasteDialog {} {
 
     set w {.ctld}
 
-    set ed(ok) 0
-    set ed(system) wcs
-    set ed(sky) fk5
-    set ed(color) green
-    set ed(width) 1
-    set ed(dash) 0
-    set ed(frame) $current(frame)
-    set ed(original) 0
+    set ed2(ok) 0
+    set ed2(system) wcs
+    set ed2(sky) fk5
+    set ed2(color) green
+    set ed2(width) 1
+    set ed2(dash) 0
+    set ed2(frame) $current(frame)
+    set ed2(original) 0
 
-    SetCoordSystem ed system sky {}
-    AdjustCoordSystem ed system
+    SetCoordSystem ed2 system sky {}
+    AdjustCoordSystem ed2 system
 
-    DialogCreate $w [msgcat::mc {Contour Paste}] ed(ok)
+    DialogCreate $w [msgcat::mc {Contour Paste}] ed2(ok)
 
     # Param
     set f [ttk::frame $w.param1]
 
-    ttk::checkbutton $f.original -text [msgcat::mc {Use Original Color/Width}] -variable ed(original)
+    ttk::checkbutton $f.original -text [msgcat::mc {Use Original Color/Width}] -variable ed2(original)
     grid $f.original -padx 2 -pady 2 -sticky w
 
     set f [ttk::frame $w.param]
 
     ttk::label $f.coordtitle -text [msgcat::mc {Coordinate System}]
 
-    CoordMenuButton $f.coordbutton ed system 1 {} {} {}
-    CoordMenuEnable $f.coordbutton.menu ed system {} {}
+    CoordMenuButton $f.coordbutton ed2 system 1 {} {} {}
+    CoordMenuEnable $f.coordbutton.menu ed2 system {} {}
 
     ttk::label $f.colortitle -text [msgcat::mc {Color}]
-    ColorMenuButton $f.colorbutton ed color {}
+    ColorMenuButton $f.colorbutton ed2 color {}
 
     ttk::label $f.widthtitle -text [msgcat::mc {Width}]
-    ttk::menubutton $f.widthbutton -textvariable ed(width) \
+    ttk::menubutton $f.widthbutton -textvariable ed2(width) \
 	-menu $f.widthbutton.menu
-    WidthDashMenu $f.widthbutton.menu ed width dash {} {}
+    WidthDashMenu $f.widthbutton.menu ed2 width dash {} {}
 
     grid $f.coordtitle $f.coordbutton -padx 2 -pady 2 -sticky w
     grid $f.colortitle $f.colorbutton -padx 2 -pady 2 -sticky w
@@ -480,12 +480,12 @@ proc ContourCPasteDialog {} {
 
     # Buttons
     set f [ttk::frame $w.buttons]
-    ttk::button $f.ok -text [msgcat::mc {OK}] -command {set ed(ok) 1} \
+    ttk::button $f.ok -text [msgcat::mc {OK}] -command {set ed2(ok) 1} \
 	-default active 
-    ttk::button $f.cancel -text [msgcat::mc {Cancel}] -command {set ed(ok) 0}
+    ttk::button $f.cancel -text [msgcat::mc {Cancel}] -command {set ed2(ok) 0}
     pack $f.ok $f.cancel -side left -expand true -padx 2 -pady 4
 
-    bind $w <Return> {set ed(ok) 1}
+    bind $w <Return> {set ed2(ok) 1}
 
     # Fini
     ttk::separator $w.sep -orient horizontal
@@ -494,27 +494,27 @@ proc ContourCPasteDialog {} {
     pack $w.param1 $w.sep2 $w.param -side top -fill both -expand true
 #    pack $w.param -side top -fill both -expand true
 
-    DialogWait $w ed(ok)
+    DialogWait $w ed2(ok)
     destroy $w
 
-    if {$ed(ok)} {
-	set ed(color) [string tolower $ed(color)]
+    if {$ed2(ok)} {
+	set ed2(color) [string tolower $ed2(color)]
 
 	if {$current(frame) == $contour(copy)} {
-	    set ed(system) physical
+	    set ed2(system) physical
 	}
 
-	set cc [$contour(copy) get contour $ed(system) fk5]
-	if {$ed(original)} {
+	set cc [$contour(copy) get contour $ed2(system) fk5]
+	if {$ed2(original)} {
 	    $current(frame) contour paste cc
 	} else {
-	    $current(frame) contour paste cc $ed(color) $ed(width) $ed(dash)
+	    $current(frame) contour paste cc $ed2(color) $ed2(width) $ed2(dash)
 	}
 	UpdateContourDialog
     }
 
-    set rr $ed(ok)
-    unset ed
+    set rr $ed2(ok)
+    unset ed2
     return $rr
 }
 
@@ -677,7 +677,7 @@ proc ContourLoadDialog {} {
 
     set fn [OpenFileDialog contourlfbox $icontour(top)]
 
-    if {$fn == {} || $current(frame) == {}} {
+    if {$fn=={} || $current(frame)=={}} {
 	return
     }
 
@@ -970,6 +970,8 @@ proc ContourBackup {ch which fdir rdir} {
 	base -
 	3d {ContourBackupBase $ch $which $fdir $rdir}
 	rgb {ContourBackupRGB $ch $which $fdir $rdir}
+	hsv {ContourBackupHSV $ch $which $fdir $rdir}
+	hls {ContourBackupHLS $ch $which $fdir $rdir}
     }
 }
 
@@ -1015,6 +1017,28 @@ proc ContourBackupRGB {ch which fdir rdir} {
     puts $ch "$which rgb channel $sav"
 }
 
+proc ContourBackupHSV {ch which fdir rdir} {
+    set sav [$which get hsv channel]
+    foreach cc {hue saturation value} {
+	$which hsv channel $cc
+	puts $ch "$which hsv channel $cc"
+	ContourBackupBase $ch $which $fdir $rdir
+    }
+    $which hsv channel $sav
+    puts $ch "$which hsv channel $sav"
+}
+
+proc ContourBackupHLS {ch which fdir rdir} {
+    set sav [$which get hls channel]
+    foreach cc {hue lightness saturation} {
+	$which hls channel $cc
+	puts $ch "$which hls channel $cc"
+	ContourBackupBase $ch $which $fdir $rdir
+    }
+    $which hls channel $sav
+    puts $ch "$which hls channel $sav"
+}
+
 proc PrefsDialogContour {} {
     global dprefs
 
@@ -1067,49 +1091,74 @@ proc ProcessContourCmd {varname iname} {
 proc ContourCmdLoad {fn} {
     global current
 
-    if {$current(frame) != {} && $fn != {}} {
-	$current(frame) contour load $fn
-	FileLast contourlfbox $fn
-	UpdateContourDialog
+    if {$current(frame)=={} || $fn=={}} {
+	return
     }
+
+    if {![file exists $fn]} {
+	Error "[msgcat::mc {File not found}]: $fn"
+	return
+    }
+    
+    $current(frame) contour load $fn
+    FileLast contourlfbox $fn
+    UpdateContourDialog
 }
 
 proc ContourCmdLoadOrg {fn sys sky color width dash} {
     global current
 
-    if {$current(frame) != {} && $fn != {}} {
-	$current(frame) contour load $color $width $dash $fn $sys $sky
-	FileLast contourlfbox $fn
-	UpdateContourDialog
+    if {$current(frame)=={} || $fn=={}} {
+	return
     }
+
+    if {![file exists $fn]} {
+	Error "[msgcat::mc {File not found}]: $fn"
+	return
+    }
+    
+    $current(frame) contour load $color $width $dash $fn $sys $sky
+    FileLast contourlfbox $fn
+    UpdateContourDialog
 }
 
 proc ContourCmdSave {fn sys sky} {
     global current
 
-    if {$current(frame) != {} && $fn != {}} {
-	$current(frame) contour save $fn $sys $sky
-	FileLast contoursfbox $fn
+    if {$current(frame)=={} || $fn=={}} {
+	return
     }
+
+    $current(frame) contour save $fn $sys $sky
+    FileLast contoursfbox $fn
 }
 
 proc ContourCmdLoadLevels {fn} {
     global current
 
-    ContourDialog
-    if {$current(frame) != {}} {
-	ContourLoadLevelsNow $fn
-	UpdateContour
+    if {$current(frame)=={} || $fn=={}} {
+	return
     }
+
+    if {![file exists $fn]} {
+	Error "[msgcat::mc {File not found}]: $fn"
+	return
+    }
+
+    ContourDialog
+    ContourLoadLevelsNow $fn
+    UpdateContour
 }
 
 proc ContourCmdSaveLevels {fn} {
     global current
 
-    ContourDialog
-    if {$current(frame) != {}} {
-	ContourSaveLevelsNow $fn
+    if {$current(frame)=={} || $fn=={}} {
+	return
     }
+
+    ContourDialog
+    ContourSaveLevelsNow $fn
 }
 
 proc ContourCmdPaste {sys sky color width dash} {
