@@ -1,4 +1,4 @@
-#  Copyright (C) 1999-2018
+#  Copyright (C) 1999-2021
 #  Smithsonian Astrophysical Observatory, Cambridge, MA, USA
 #  For conditions of distribution and use, see copyright notice in "copyright"
 
@@ -43,7 +43,7 @@ proc CrosshairArrowKey {which x y} {
     UpdateColormapLevelMosaic $which $X $Y canvas
     UpdateInfoBox $which $X $Y canvas
     UpdatePixelTableDialog $which $X $Y canvas
-    UpdateGraphData $which $X $Y canvas
+    UpdateGraphsData $which $X $Y canvas
 }
 
 proc CrosshairTo {x y sys sky} {
