@@ -115,7 +115,7 @@ proc FPDialog {varname title url instr format action} {
 
     # file
     ThemeMenu $mb.file
-    $mb.file add command -label "[msgcat::mc {Save}]..." \
+    $mb.file add command -label [msgcat::mc {Save}] \
 	-command [list TBLSaveVOTFile $varname] -accelerator "${ds9(ctrl)}S"
     $mb.file add separator
     $mb.file add cascade -label [msgcat::mc {Export}] -menu $mb.file.export
@@ -154,7 +154,7 @@ proc FPDialog {varname title url instr format action} {
 	cxcpublic {}
     }
     $mb.file add separator
-    $mb.file add command -label "[msgcat::mc {Print}]..." \
+    $mb.file add command -label [msgcat::mc {Print}] \
 	-command [list TBLPrint $varname] -accelerator "${ds9(ctrl)}P"
     $mb.file add separator
     $mb.file add command -label [msgcat::mc {Close}] \
@@ -162,9 +162,9 @@ proc FPDialog {varname title url instr format action} {
 
     # Export
     ThemeMenu $mb.file.export
-    $mb.file.export add command -label "[msgcat::mc {Starbase}]..." \
+    $mb.file.export add command -label [msgcat::mc {Starbase}] \
 	-command [list TBLSaveRDBFile $varname]
-    $mb.file.export add command -label "[msgcat::mc {Tab-Separated-Value}]..." \
+    $mb.file.export add command -label [msgcat::mc {Tab-Separated-Value}] \
 	-command [list TBLSaveTSVFile $varname]
 
     # edit
@@ -529,7 +529,7 @@ proc FPDialogUpdate {varname} {
 	    hla {$var(mb).file entryconfig [msgcat::mc {Copy to Regions}] -state normal}
 	    cxcpublic {}
 	}
-	$var(mb).file entryconfig "[msgcat::mc {Print}]..." -state normal
+	$var(mb).file entryconfig [msgcat::mc {Print}] -state normal
 
 	$var(top).buttons.clear configure -state normal
     } else {
@@ -539,7 +539,7 @@ proc FPDialogUpdate {varname} {
 	    hla {$var(mb).file entryconfig [msgcat::mc {Copy to Regions}] -state disabled}
 	    cxcpublic {}
 	}
-	$var(mb).file entryconfig "[msgcat::mc {Print}]..." -state disabled
+	$var(mb).file entryconfig [msgcat::mc {Print}] -state disabled
 
 	$var(top).buttons.clear configure -state disabled
     }
