@@ -99,15 +99,15 @@ proc GridDefault {} {
     set grid(textlab,color) black
 }
 
-proc GridUpdateCurrent {} {
+proc UpdateGridCurrent {} {
     global current
     
     if {$current(frame) != {}} {
-	GridUpdate $current(frame)
+	UpdateGrid $current(frame)
     }
 }
 
-proc GridUpdate {which} {
+proc UpdateGrid {which} {
     global grid
 
     GridAdjustOptions $which
@@ -121,11 +121,11 @@ proc GridUpdate {which} {
     }
 }	    
 
-proc GridUpdateZoom {} {
+proc UpdateGridZoom {} {
     global grid
 
     if {$grid(type) == "publication"} {
-	GridUpdateCurrent
+	UpdateGridCurrent
     }
 }
 
@@ -831,19 +831,19 @@ proc GridApplyDialog {} {
     global grid
 
     set grid(view) 1
-    GridUpdateCurrent
+    UpdateGridCurrent
 }
 
 proc GridResetDialog {} {
     GridDefault
-    GridUpdateCurrent
+    UpdateGridCurrent
 }
 
 proc GridClearDialog {} {
     global grid
 
     set grid(view) 0
-    GridUpdateCurrent
+    UpdateGridCurrent
 }
 
 proc GridDestroyDialog {} {
@@ -978,6 +978,7 @@ proc UpdateGridDialog {} {
 		}
 	    }
 
+	    set grid(frame) $current(frame)
 	    if {[$current(frame) has fits]} {
 		CoordMenuEnable $igrid(mb).coord grid system sky skyformat
 	    } else {
@@ -1013,7 +1014,7 @@ proc GridLoad {fn} {
 	FixFontVar grid(title,weight) grid(title,slant) grid(title,style)
 
 	set grid(view) 1
-	GridUpdateCurrent
+	UpdateGridCurrent
     }
 }
 
@@ -1052,7 +1053,7 @@ proc GridDefaultFormat1 {} {
 	detector -
 	amplifier {return {}}
 	default {
-	    if {[$current(frame) has wcs celestial $grid(system)]} {
+	    if {[$current(frame) has wcs equatorial $grid(system)]} {
 		switch $grid(sky) {
 		    fk4 -
 		    fk5 -
@@ -1072,7 +1073,6 @@ proc GridDefaultFormat1 {} {
 			}
 		    }
 		}
-		return {}
 	    }
 	    if {[$current(frame) has wcs celestial $grid(system)]} {
 		switch $grid(skyformat) {
@@ -1080,7 +1080,6 @@ proc GridDefaultFormat1 {} {
 		    sexagesimal {return {dms.1}}
 		    hms {return {ldms}}
 		}
-		return {}
 	    }
 	}
     }
@@ -1096,7 +1095,7 @@ proc GridDefaultFormat2 {} {
 	detector -
 	amplifier {return {}}
 	default {
-	    if {[$current(frame) has wcs celestial $grid(system)]} {
+	    if {[$current(frame) has wcs equatorial $grid(system)]} {
 		switch $grid(sky) {
 		    fk4 -
 		    fk5 -
@@ -1116,7 +1115,6 @@ proc GridDefaultFormat2 {} {
 			}
 		    }
 		}
-		return {}
 	    }
 	    if {[$current(frame) has wcs celestial $grid(system)]} {
 		switch $grid(skyformat) {
@@ -1124,7 +1122,6 @@ proc GridDefaultFormat2 {} {
 		    sexagesimal {return {dms.1}}
 		    hms {return {ldms}}
 		}
-		return {}
 	    }
 	}
     }
