@@ -49,7 +49,7 @@ proc HVReset {varname} {
     if {[info exists var(token)]} {
 	global debug
 	if {$debug(tcl,hv)} {
-	    puts stderr "HVReset ***cleanup***"
+	    puts stderr "HVReset"
 	}
 	http::cleanup $var(token)
 	unset var(token)
@@ -358,7 +358,6 @@ proc HVProcessURLHTTP {varname url query rr sync} {
 					 -binary 1 \
 					 -channel $var(ch)]
 	}]} {
-	    # reset errorInfo (may be set in http::geturl)
 	    global errorInfo
 	    set errorInfo {}
 
@@ -379,7 +378,6 @@ proc HVProcessURLHTTP {varname url query rr sync} {
 					 -channel $var(ch) \
 					 -command [list HVProcessURLHTTPFinish $varname]]
 	}]} {
-	    # reset errorInfo (may be set in http::geturl)
 	    global errorInfo
 	    set errorInfo {}
 
@@ -401,7 +399,7 @@ proc HVProcessURLHTTPFinish {varname token} {
 	puts stderr "HVProcessURLHTTPFinish"
     }
 
-    catch {close $var(ch)}
+    close $var(ch)
 
     if {!($var(active))} {
 	HVCancelled $varname
@@ -1333,6 +1331,7 @@ proc HVParseXPASet {varname} {
 
 	InitError hv
 	CommSet $var(fn) [HVParseMimeParam $varname paramlist] 1
+	InitError tcl
     } else {
 	HVError $varname "[msgcat::mc {Unable to match target with XPA Mime request}] $var(url)"
     }
@@ -1817,8 +1816,6 @@ proc HVImageURL {varname url width height} {
 		    set ii 0
 		    continue
 		}
-
-		# reset errorInfo (may be set in http::geturl)
 		global errorInfo
 		set errorInfo {}
 
