@@ -25,7 +25,9 @@ proc MultiLoad {{layer {}} {mode {}}} {
 		}
 		CreateFrame
 	    }
-	    rgb {CreateFrame}
+	    rgb -
+	    hsv -
+	    hls {CreateFrame}
 	}
     } else {
 	CreateFrame
@@ -40,6 +42,7 @@ proc MultiLoad {{layer {}} {mode {}}} {
     }
 }
 
+# only used by rgb frame
 proc MultiLoadRGB {} {
     global ds9
     global current
@@ -52,6 +55,8 @@ proc MultiLoadRGB {} {
     if {$current(frame) != {}} {
 	switch -- [$current(frame) get type] {
 	    base -
+	    hsv -
+	    hls -
 	    3d {CreateRGBFrame}
 	    rgb {
 		if {![$current(frame) has fits]} {
@@ -73,6 +78,78 @@ proc MultiLoadRGB {} {
     }
 }
 
+# only used by hls frame
+proc MultiLoadHLS {} {
+    global ds9
+    global current
+
+    global debug
+    if {$debug(tcl,layout)} {
+	puts stderr "MultiLoadHLS"
+    }
+
+    if {$current(frame) != {}} {
+	switch -- [$current(frame) get type] {
+	    base -
+	    rgb -
+	    hsv -
+	    3d {CreateHLSFrame}
+	    hls {
+		if {![$current(frame) has fits]} {
+		    return
+		}
+		CreateHLSFrame
+	    }
+	}
+    } else {
+	CreateHLSFrame
+	return
+    }
+
+    # go into tile mode if more than one
+    set cnt [llength $ds9(frames)]
+    if {$cnt > 1 && $current(display) != "tile"} {
+	set current(display) tile
+	DisplayMode
+    }
+}
+
+# only used by hsv frame
+proc MultiLoadHSV {} {
+    global ds9
+    global current
+
+    global debug
+    if {$debug(tcl,layout)} {
+	puts stderr "MultiLoadHSV"
+    }
+
+    if {$current(frame) != {}} {
+	switch -- [$current(frame) get type] {
+	    base -
+	    rgb -
+	    hls -
+	    3d {CreateHSVFrame}
+	    hsv {
+		if {![$current(frame) has fits]} {
+		    return
+		}
+		CreateHSVFrame
+	    }
+	}
+    } else {
+	CreateHSVFrame
+	return
+    }
+
+    # go into tile mode if more than one
+    set cnt [llength $ds9(frames)]
+    if {$cnt > 1 && $current(display) != "tile"} {
+	set current(display) tile
+	DisplayMode
+    }
+}
+
 # used by backup
 proc ProcessLoad {{err 1}} {
     global current
@@ -109,12 +186,14 @@ proc ProcessLoad {{err 1}} {
     if {[catch {
 	switch -- $loadParam(load,type) {
 	    alloc -
-	    allocgz {$current(frame) load $loadParam(file,type) \
+	    allocgz {
+		$current(frame) load $loadParam(file,type) \
 			 $loadParam(file,mode) \
 			 \{$loadParam(file,name)\} \
 			 $loadParam(load,type) \
 			 \{$loadParam(file,fn)\} \
-			 $loadParam(load,layer)}
+			 $loadParam(load,layer)
+	    }
 	    channel {
 		fconfigure $loadParam(channel,name) -translation binary \
 		    -encoding binary
@@ -129,46 +208,59 @@ proc ProcessLoad {{err 1}} {
 		catch {close $loadParam(channel,name)}
 	    }
 	    mmap -
-	    mmapincr {$current(frame) load $loadParam(file,type) \
+	    mmapincr {
+		$current(frame) load $loadParam(file,type) \
 			  $loadParam(file,mode) \
 			  \{$loadParam(file,name)\} \
 			  $loadParam(load,type) \
-			  $loadParam(load,layer)}
-	    smmap {$current(frame) load $loadParam(file,type) \
+			  $loadParam(load,layer)
+	    }
+	    smmap {
+		$current(frame) load $loadParam(file,type) \
 		       $loadParam(file,mode) \
 		       \{$loadParam(file,header)\} \
 		       \{$loadParam(file,name)\} \
 		       $loadParam(load,type) \
-		       $loadParam(load,layer)}
-	    shared {$current(frame) load $loadParam(file,type) \
+		       $loadParam(load,layer)
+	    }
+	    shared {
+		$current(frame) load $loadParam(file,type) \
 			$loadParam(file,mode) \
 			\{$loadParam(file,name)\} \
 			$loadParam(load,type) \
 			$loadParam(shared,idtype) \
 			$loadParam(shared,id) \
-			$loadParam(load,layer)}
-	    sshared {$current(frame) load $loadParam(file,type) \
+			$loadParam(load,layer)
+	    }
+	    sshared {
+		$current(frame) load $loadParam(file,type) \
 			 $loadParam(file,mode) \
 			 \{$loadParam(file,name)\} \
 			 $loadParam(load,type) \
 			 $loadParam(shared,idtype) \
 			 $loadParam(shared,hdr) \
 			 $loadParam(shared,id) \
-			 $loadParam(load,layer)}
+			 $loadParam(load,layer)
+	    }
 	    socket -
-	    socketgz {$current(frame) load $loadParam(file,type) \
+	    socketgz {
+		$current(frame) load $loadParam(file,type) \
 			  $loadParam(file,mode) \
 			  \{$loadParam(file,name)\} \
 			  $loadParam(load,type) \
 			  $loadParam(socket,id) \
-			  $loadParam(load,layer)}
-	    var {$current(frame) load $loadParam(file,type) \
+			  $loadParam(load,layer)
+	    }
+	    var {
+		$current(frame) load $loadParam(file,type) \
 		     $loadParam(file,mode) \
 		     \{$loadParam(file,name)\} \
 		     $loadParam(load,type) \
 		     $loadParam(var,name) \
-		     $loadParam(load,layer)}
-	    photo {$current(frame) load $loadParam(file,type) \
+		     $loadParam(load,layer)
+	    }
+	    photo {
+		$current(frame) load $loadParam(file,type) \
 		       $loadParam(file,mode) \
 		       $loadParam(var,name) \{$loadParam(file,name)\}
 	    }
@@ -184,8 +276,7 @@ proc ProcessLoad {{err 1}} {
 
     # save loadParam
     switch -- [$current(frame) get type] {
-	base -
-	3d {ProcessLoadSaveParams $current(frame)}
+	base {ProcessLoadSaveParams $current(frame)}
 	rgb {
 	    switch -- $loadParam(file,mode) {
 		{rgb image} -
@@ -196,6 +287,27 @@ proc ProcessLoad {{err 1}} {
 		}
 	    }
 	}
+	hls {
+	    switch -- $loadParam(file,mode) {
+		{hls image} -
+		{hls cube} {ProcessLoadSaveParams $current(frame)}
+		default {
+		    ProcessLoadSaveParams \
+			"$current(frame)[$current(frame) get hls channel]"
+		}
+	    }
+	}
+	hsv {
+	    switch -- $loadParam(file,mode) {
+		{hsv image} -
+		{hsv cube} {ProcessLoadSaveParams $current(frame)}
+		default {
+		    ProcessLoadSaveParams \
+			"$current(frame)[$current(frame) get hsv channel]"
+		}
+	    }
+	}
+	3d {ProcessLoadSaveParams $current(frame)}
     }
 
     unset loadParam
@@ -257,7 +369,7 @@ proc LoadUpdate {} {
     }
 
     # generate grid so UpdateMenu is correct
-    GridUpdateCurrent
+    UpdateGridCurrent
 
     # generate contour so UpdateMenu is correct
     UpdateContourScale
