@@ -203,10 +203,6 @@ proc MarkerAnalysisPlot2dDeleteCB {frame id} {
     upvar #0 $vvarname vvar
     global $vvarname
 
-    # clear any errors
-    global errorInfo
-    set errorInfo {}
-
     PlotDestroy $vvarname
 
     # clear extra vectors
