@@ -113,7 +113,7 @@ proc MaskDialog {} {
     $mb add cascade -label [msgcat::mc {Blend}] -menu $mb.blend
 
     ThemeMenu $mb.file
-    $mb.file add command -label "[msgcat::mc {Open}]..." \
+    $mb.file add command -label [msgcat::mc {Open}] \
 	-command [list OpenDialog fits mask] -accelerator "${ds9(ctrl)}O"
     $mb.file add cascade -label [msgcat::mc {Open as}] \
 	-menu $mb.file.open
@@ -128,19 +128,19 @@ proc MaskDialog {} {
 	-command MaskDestroyDialog -accelerator "${ds9(ctrl)}W"
 
     ThemeMenu $mb.file.open
-    $mb.file.open add command -label "[msgcat::mc {Mosaic WCS}]..." \
+    $mb.file.open add command -label [msgcat::mc {Mosaic WCS}] \
 	-command [list OpenDialog mosaicimagewcs mask]
-    $mb.file.open add command -label "[msgcat::mc {Mosaic WCS Segment}]..." \
+    $mb.file.open add command -label [msgcat::mc {Mosaic WCS Segment}] \
 	-command [list OpenDialog mosaicwcs mask]
-    $mb.file.open add command -label "[msgcat::mc {Mosaic IRAF}]..." \
+    $mb.file.open add command -label [msgcat::mc {Mosaic IRAF}] \
 	-command [list OpenDialog mosaicimageiraf mask]
-    $mb.file.open add command -label "[msgcat::mc {Mosaic IRAF Segment}]..." \
+    $mb.file.open add command -label [msgcat::mc {Mosaic IRAF Segment}] \
 	-command [list OpenDialog mosaiciraf mask]
-    $mb.file.open add command -label "[msgcat::mc {Mosaic WFPC2}]..." \
+    $mb.file.open add command -label [msgcat::mc {Mosaic WFPC2}] \
 	-command [list OpenDialog mosaicimagewfpc2 mask]
 
     ThemeMenu $mb.file.import
-    $mb.file.import add command -label "[msgcat::mc {Array}]..." \
+    $mb.file.import add command -label [msgcat::mc {Array}] \
 	-command [list ImportDialog array mask]
     $mb.file.import add command -label {NRRD} \
 	-command [list ImportDialog nrrd mask]
@@ -226,12 +226,12 @@ proc UpdateMaskMenu {} {
     switch -- [$current(frame) get type] {
 	base {
 	    $ds9(mb).analysis entryconfig \
-		"[msgcat::mc {Mask Parameters}]..." -state normal
+		[msgcat::mc {Mask Parameters}] -state normal
 	}
 	3d -
 	rgb {
 	    $ds9(mb).analysis entryconfig \
-		"[msgcat::mc {Mask Parameters}]..." -state disabled
+		[msgcat::mc {Mask Parameters}] -state disabled
 	}
     }
 }
