@@ -15,6 +15,10 @@ proc FrameMainMenu {} {
 	-command CreateFrame
     $ds9(mb).frame add command -label [msgcat::mc {New Frame RGB}] \
 	-command CreateRGBFrame
+    $ds9(mb).frame add command -label [msgcat::mc {New Frame HSV}] \
+	-command CreateHSVFrame
+    $ds9(mb).frame add command -label [msgcat::mc {New Frame HLS}] \
+	-command CreateHLSFrame
     $ds9(mb).frame add command -label [msgcat::mc {New Frame 3D}] \
 	-command Create3DFrame
     $ds9(mb).frame add separator
@@ -64,6 +68,10 @@ proc FrameMainMenu {} {
 	-command CubeDialog
     $ds9(mb).frame add command -label [msgcat::mc {RGB}] \
 	-command RGBDialog
+    $ds9(mb).frame add command -label [msgcat::mc {HSV}] \
+	-command HSVDialog
+    $ds9(mb).frame add command -label [msgcat::mc {HLS}] \
+	-command HLSDialog
     $ds9(mb).frame add command -label [msgcat::mc {3d}] \
 	-command 3DDialog
     $ds9(mb).frame add separator
@@ -397,6 +405,8 @@ proc ButtonsFrameDef {} {
     array set pbuttons {
 	frame,new 1
 	frame,newrgb 1
+	frame,newhsv 1
+	frame,newhls 1
 	frame,new3d 1
 	frame,delete 1
 	frame,deleteall 0
@@ -478,6 +488,8 @@ proc ButtonsFrameDef {} {
 	frame,last 1
 	frame,cube 0
 	frame,rgb 0
+	frame,hsv 0
+	frame,hls 0
 	frame,3d 0
 	frame,size 0
     }
@@ -494,6 +506,10 @@ proc CreateButtonsFrame {} {
 	[string tolower [msgcat::mc {New}]] CreateFrame
     ButtonButton $ds9(buttons).frame.newrgb \
 	[string tolower [msgcat::mc {RGB}]] CreateRGBFrame
+    ButtonButton $ds9(buttons).frame.newhsv \
+	[string tolower [msgcat::mc {HSV}]] CreateHSVFrame
+    ButtonButton $ds9(buttons).frame.newhls \
+	[string tolower [msgcat::mc {HLS}]] CreateHLSFrame
     ButtonButton $ds9(buttons).frame.new3d \
 	[string tolower [msgcat::mc {3d}]] Create3DFrame
 
@@ -697,6 +713,10 @@ proc CreateButtonsFrame {} {
 	[string tolower [msgcat::mc {Cube}]] CubeDialog
     ButtonButton $ds9(buttons).frame.rgb \
 	[string tolower [msgcat::mc {RGB}]] RGBDialog
+    ButtonButton $ds9(buttons).frame.hsv \
+	[string tolower [msgcat::mc {HSV}]] HSVDialog
+    ButtonButton $ds9(buttons).frame.hls \
+	[string tolower [msgcat::mc {HLS}]] HLSDialog
     ButtonButton $ds9(buttons).frame.3d \
 	[string tolower [msgcat::mc {3d}]] 3DDialog
 
@@ -706,6 +726,8 @@ proc CreateButtonsFrame {} {
     set buttons(frame) "
         $ds9(buttons).frame.new pbuttons(frame,new)
         $ds9(buttons).frame.newrgb pbuttons(frame,newrgb)
+        $ds9(buttons).frame.newhsv pbuttons(frame,newhsv)
+        $ds9(buttons).frame.newhls pbuttons(frame,newhls)
         $ds9(buttons).frame.new3d pbuttons(frame,new3d)
         $ds9(buttons).frame.delete pbuttons(frame,delete)
         $ds9(buttons).frame.deleteall pbuttons(frame,deleteall)
@@ -787,6 +809,8 @@ proc CreateButtonsFrame {} {
         $ds9(buttons).frame.last pbuttons(frame,last)
         $ds9(buttons).frame.cube pbuttons(frame,cube)
         $ds9(buttons).frame.rgb pbuttons(frame,rgb)
+        $ds9(buttons).frame.hsv pbuttons(frame,hsv)
+        $ds9(buttons).frame.hls pbuttons(frame,hls)
         $ds9(buttons).frame.3d pbuttons(frame,3d)
         $ds9(buttons).frame.size pbuttons(frame,size)
     "
@@ -805,6 +829,10 @@ proc PrefsDialogButtonbarFrame {f} {
 	-variable pbuttons(frame,new) -command {UpdateButtons buttons(frame)}
     $m add checkbutton -label [msgcat::mc {New Frame RGB}] \
 	-variable pbuttons(frame,newrgb) -command {UpdateButtons buttons(frame)}
+    $m add checkbutton -label [msgcat::mc {New Frame HSV}] \
+	-variable pbuttons(frame,newhsv) -command {UpdateButtons buttons(frame)}
+    $m add checkbutton -label [msgcat::mc {New Frame HLS}] \
+	-variable pbuttons(frame,newhls) -command {UpdateButtons buttons(frame)}
     $m add checkbutton -label [msgcat::mc {New Frame 3D}] \
 	-variable pbuttons(frame,new3d) -command {UpdateButtons buttons(frame)}
     $m add separator
@@ -847,6 +875,10 @@ proc PrefsDialogButtonbarFrame {f} {
 	-variable pbuttons(frame,cube) -command {UpdateButtons buttons(frame)}
     $m add checkbutton -label [msgcat::mc {RGB}] \
 	-variable pbuttons(frame,rgb) -command {UpdateButtons buttons(frame)}
+    $m add checkbutton -label [msgcat::mc {HSV}] \
+	-variable pbuttons(frame,hsv) -command {UpdateButtons buttons(frame)}
+    $m add checkbutton -label [msgcat::mc {HLS}] \
+	-variable pbuttons(frame,hls) -command {UpdateButtons buttons(frame)}
     $m add checkbutton -label [msgcat::mc {3d}] \
 	-variable pbuttons(frame,3d) -command {UpdateButtons buttons(frame)}
     $m add separator
@@ -1094,11 +1126,6 @@ proc UpdateFrameMenu {} {
 	$ds9(mb).frame entryconfig [msgcat::mc {Reset Frame}] -state normal
 	$ds9(mb).frame entryconfig [msgcat::mc {Refresh Frame}] -state normal
 
-#	$ds9(mb).frame entryconfig [msgcat::mc {Single Frame}] -state normal
-#	$ds9(mb).frame entryconfig [msgcat::mc {Tile Frames}] -state normal
-#	$ds9(mb).frame entryconfig [msgcat::mc {Blink Frames}] -state normal
-#	$ds9(mb).frame entryconfig [msgcat::mc {Fade Frames}] -state normal
-
 	$ds9(mb).frame entryconfig [msgcat::mc {Match}] -state normal
 	$ds9(mb).frame entryconfig [msgcat::mc {Lock}] -state normal
 
@@ -1116,11 +1143,6 @@ proc UpdateFrameMenu {} {
 	$ds9(buttons).frame.reset configure -state normal
 	$ds9(buttons).frame.refresh configure -state normal
 
-#	$ds9(buttons).frame.single configure -state normal
-#	$ds9(buttons).frame.tile configure -state normal
-#	$ds9(buttons).frame.blink configure -state normal
-#	$ds9(buttons).frame.fade configure -state normal
-
 	$ds9(buttons).frame.movefirst configure -state normal
 	$ds9(buttons).frame.moveprev configure -state normal
 	$ds9(buttons).frame.movenext configure -state normal
@@ -1138,11 +1160,6 @@ proc UpdateFrameMenu {} {
 	$ds9(mb).frame entryconfig [msgcat::mc {Reset Frame}] -state disabled
 	$ds9(mb).frame entryconfig [msgcat::mc {Refresh Frame}] -state disabled
 
-#	$ds9(mb).frame entryconfig [msgcat::mc {Single Frame}] -state disabled
-#	$ds9(mb).frame entryconfig [msgcat::mc {Tile Frames}] -state disabled
-#	$ds9(mb).frame entryconfig [msgcat::mc {Blink Frames}] -state disabled
-#	$ds9(mb).frame entryconfig [msgcat::mc {Fade Frames}] -state disabled
-
 	$ds9(mb).frame entryconfig [msgcat::mc {Match}] -state disabled
 	$ds9(mb).frame entryconfig [msgcat::mc {Lock}] -state disabled
 
@@ -1160,11 +1177,6 @@ proc UpdateFrameMenu {} {
 	$ds9(buttons).frame.reset configure -state disabled
 	$ds9(buttons).frame.refresh configure -state disabled
 
-#	$ds9(buttons).frame.single configure -state disabled
-#	$ds9(buttons).frame.tile configure -state disabled
-#	$ds9(buttons).frame.blink configure -state disabled
-#	$ds9(buttons).frame.fade configure -state disabled
-
 	$ds9(buttons).frame.movefirst configure -state disabled
 	$ds9(buttons).frame.moveprev configure -state disabled
 	$ds9(buttons).frame.movenext configure -state disabled
@@ -1177,45 +1189,26 @@ proc UpdateFrameMenu {} {
     }
 
     if {$current(frame) != {}} {
-	$ds9(mb).frame entryconfig [msgcat::mc {Cube}] \
-	    -state normal
+	$ds9(mb).frame entryconfig [msgcat::mc {Cube}] -state normal
+	$ds9(mb).frame entryconfig [msgcat::mc {RGB}] -state normal
+	$ds9(mb).frame entryconfig [msgcat::mc {HSV}] -state normal
+	$ds9(mb).frame entryconfig [msgcat::mc {HLS}] -state normal
+	$ds9(mb).frame entryconfig [msgcat::mc {3d}] -state normal
 	$ds9(buttons).frame.cube configure -state normal
-
-	switch -- [$current(frame) get type] {
-	    base {
-		$ds9(mb).frame entryconfig [msgcat::mc {RGB}] \
-		    -state disabled
-		$ds9(mb).frame entryconfig [msgcat::mc {3d}] \
-		    -state normal
-		$ds9(buttons).frame.rgb configure -state disabled
-		$ds9(buttons).frame.3d configure -state normal
-	    }
-	    rgb {
-		$ds9(mb).frame entryconfig [msgcat::mc {RGB}] \
-		    -state normal
-		$ds9(mb).frame entryconfig [msgcat::mc {3d}] \
-		    -state disabled
-		$ds9(buttons).frame.rgb configure -state normal
-		$ds9(buttons).frame.3d configure -state disabled
-	    }
-	    3d {
-		$ds9(mb).frame entryconfig [msgcat::mc {RGB}] \
-		    -state disabled
-		$ds9(mb).frame entryconfig [msgcat::mc {3d}]  \
-		    -state normal
-		$ds9(buttons).frame.rgb configure -state disabled
-		$ds9(buttons).frame.3d configure -state normal
-	    }
-	}
+	$ds9(buttons).frame.rgb configure -state normal
+	$ds9(buttons).frame.hsv configure -state normal
+	$ds9(buttons).frame.hls configure -state normal
+	$ds9(buttons).frame.3d configure -state normal
     } else {
-	$ds9(mb).frame entryconfig [msgcat::mc {Cube}] \
-	    -state disabled
-	$ds9(mb).frame entryconfig [msgcat::mc {RGB}] \
-	    -state disabled
-	$ds9(mb).frame entryconfig [msgcat::mc {3d}] \
-	    -state disabled
+	$ds9(mb).frame entryconfig [msgcat::mc {Cube}] -state disabled
+	$ds9(mb).frame entryconfig [msgcat::mc {RGB}] -state disabled
+	$ds9(mb).frame entryconfig [msgcat::mc {HSV}] -state disabled
+	$ds9(mb).frame entryconfig [msgcat::mc {HLS}] -state disabled
+	$ds9(mb).frame entryconfig [msgcat::mc {3d}] -state disabled
 	$ds9(buttons).frame.cube configure -state disabled
 	$ds9(buttons).frame.rgb configure -state disabled
+	$ds9(buttons).frame.hsv configure -state disabled
+	$ds9(buttons).frame.hls configure -state disabled
 	$ds9(buttons).frame.3d configure -state disabled
     }
 }
