@@ -1,4 +1,4 @@
-#  Copyright (C) 1999-2018
+#  Copyright (C) 1999-2021
 #  Smithsonian Astrophysical Observatory, Cambridge, MA, USA
 #  For conditions of distribution and use, see copyright notice in "copyright"
 
@@ -68,6 +68,7 @@ proc PlotDataSetOne {varname dim data} {
     set var(graph,ds,line,fill,color) $pap(graph,ds,line,fill,color)
 
     set var(graph,ds,line,shape,symbol) $pap(graph,ds,line,shape,symbol)
+    set var(graph,ds,line,shape,size) $pap(graph,ds,line,shape,size)
     set var(graph,ds,line,shape,color) $pap(graph,ds,line,shape,color)
     set var(graph,ds,line,shape,fill) $pap(graph,ds,line,shape,fill)
 
@@ -78,10 +79,12 @@ proc PlotDataSetOne {varname dim data} {
     set var(graph,ds,bar,color) $pap(graph,ds,bar,color)
     set var(graph,ds,bar,width) $pap(graph,ds,bar,width)
 
+    # backward compatibility
     # Scatter
-    set var(graph,ds,scatter,symbol) $pap(graph,ds,scatter,symbol)
-    set var(graph,ds,scatter,color) $pap(graph,ds,scatter,color)
-    set var(graph,ds,scatter,fill) $pap(graph,ds,scatter,fill)
+    set var(graph,ds,scatter,shape,symbol) $pap(graph,ds,scatter,shape,symbol)
+    set var(graph,ds,scatter,shape,size) $pap(graph,ds,scatter,shape,size)
+    set var(graph,ds,scatter,shape,color) $pap(graph,ds,scatter,shape,color)
+    set var(graph,ds,scatter,shape,fill) $pap(graph,ds,scatter,shape,fill)
 
     # Error
     set var(graph,ds,error) $pap(graph,ds,error)
@@ -296,6 +299,7 @@ proc PlotDupDataSet {varname} {
     set var(graph,ds,line,fill,color) $var($cc,$mm,line,fill,color)
 
     set var(graph,ds,line,shape,symbol) $var($cc,$mm,line,shape,symbol)
+    set var(graph,ds,line,shape,size) $var($cc,$mm,line,shape,size)
     set var(graph,ds,line,shape,color) $var($cc,$mm,line,shape,color)
     set var(graph,ds,line,shape,fill) $var($cc,$mm,line,shape,fill)
 
@@ -306,10 +310,12 @@ proc PlotDupDataSet {varname} {
     set var(graph,ds,bar,color) $var($cc,$mm,bar,color)
     set var(graph,ds,bar,width) $var($cc,$mm,bar,width)
 
+    # backward compatibility
     # Scatter
-    set var(graph,ds,scatter,symbol) $var($cc,$mm,scatter,symbol)
-    set var(graph,ds,scatter,color) $var($cc,$mm,scatter,color)
-    set var(graph,ds,scatter,fill) $var($cc,$mm,scatter,fill)
+    set var(graph,ds,scatter,shape,symbol) $var($cc,$mm,scatter,shape,symbol)
+    set var(graph,ds,scatter,shape,size) $var($cc,$mm,scatter,shape,size)
+    set var(graph,ds,scatter,shape,color) $var($cc,$mm,scatter,shape,color)
+    set var(graph,ds,scatter,shape,fill) $var($cc,$mm,scatter,shape,fill)
 
     # Error
     set var(graph,ds,error) $var($cc,$mm,error)
