@@ -213,6 +213,13 @@ proc SavePrefs {} {
     puts $ch "array set pblink \{ [array get pblink] \}"
     puts $ch {array set blink [array get pblink]}
 
+    global fade
+    global pfade
+    puts $ch "global fade"
+    puts $ch "global pfade"
+    puts $ch "array set pfade \{ [array get pfade] \}"
+    puts $ch {array set fade [array get pfade]}
+
     global tile
     global ptile
     puts $ch "global tile"
@@ -471,6 +478,7 @@ proc FixPrefs {version} {
 	    FixPrefs8.0to8.1
 	    FixPrefs8.1to8.2
 	    FixPrefs8.2to8.3
+	    FixPrefs8.3to8.4
 	}
 	6.0 {
 	    FixPrefs6.0to6.1 
@@ -486,6 +494,7 @@ proc FixPrefs {version} {
 	    FixPrefs8.0to8.1
 	    FixPrefs8.1to8.2
 	    FixPrefs8.2to8.3
+	    FixPrefs8.3to8.4
 	}
 	6.1 -
 	6.1.1 -
@@ -502,6 +511,7 @@ proc FixPrefs {version} {
 	    FixPrefs8.0to8.1
 	    FixPrefs8.1to8.2
 	    FixPrefs8.2to8.3
+	    FixPrefs8.3to8.4
 	}
 	6.2 {
 	    FixPrefs6.2to7.0
@@ -515,6 +525,7 @@ proc FixPrefs {version} {
 	    FixPrefs8.0to8.1
 	    FixPrefs8.1to8.2
 	    FixPrefs8.2to8.3
+	    FixPrefs8.3to8.4
 	}
 	7.0 -
 	7.0.1 {
@@ -528,6 +539,7 @@ proc FixPrefs {version} {
 	    FixPrefs8.0to8.1
 	    FixPrefs8.1to8.2
 	    FixPrefs8.2to8.3
+	    FixPrefs8.3to8.4
 	}
 	7.1 {
 	    FixPrefs7.1to7.2
@@ -539,6 +551,7 @@ proc FixPrefs {version} {
 	    FixPrefs8.0to8.1
 	    FixPrefs8.1to8.2
 	    FixPrefs8.2to8.3
+	    FixPrefs8.3to8.4
 	}
 	7.2 {
 	    FixPrefs7.2to7.3
@@ -560,6 +573,7 @@ proc FixPrefs {version} {
 	    FixPrefs8.0to8.1
 	    FixPrefs8.1to8.2
 	    FixPrefs8.2to8.3
+	    FixPrefs8.3to8.4
 	}
 	7.4 {
 	    FixPrefs7.4to7.5
@@ -575,28 +589,36 @@ proc FixPrefs {version} {
 	    FixPrefs8.0to8.1
 	    FixPrefs8.1to8.2
 	    FixPrefs8.2to8.3
+	    FixPrefs8.3to8.4
 	}
 	7.6 {
 	    FixPrefs7.6to8.0
 	    FixPrefs8.0to8.1
 	    FixPrefs8.1to8.2
 	    FixPrefs8.2to8.3
+	    FixPrefs8.3to8.4
 	}
 	8.0 {
 	    FixPrefs8.0to8.1
 	    FixPrefs8.1to8.2
 	    FixPrefs8.2to8.3
+	    FixPrefs8.3to8.4
 	}
 	8.1 {
 	    FixPrefs8.1to8.2
 	    FixPrefs8.2to8.3
+	    FixPrefs8.3to8.4
 	}
 	8.2 {
 	    FixPrefs8.2to8.3
+	    FixPrefs8.3to8.4
 	}
 	8.3 {
 	    # beta fix
 	    FixPrefs8.3to8.3
+	    FixPrefs8.3to8.4
+	}
+	8.4 {
 	}
     }
 }
@@ -650,6 +672,17 @@ proc FixPrefsVarOld {} {
     }
 }
 
+proc FixPrefs8.3to8.4 {} {
+    global ps
+
+    switch $ps(resolution) {
+	screen -
+	Screen -
+	SCREEN {set ps(resolution) 96}
+	default {}
+    }
+}
+
 proc FixPrefs8.3to8.3 {} {
     global pcolorbar
     switch $pcolorbar(orientation) {
