@@ -41,7 +41,7 @@ proc PrefsDialog {{which {}}} {
     set dprefs(listbox) [ttk::treeview $f.box \
 			  -yscroll [list $f.scroll set] \
 			  -selectmode browse \
-			  -height 28 \
+			  -height 29 \
 			  -show tree \
 			 ]
 
@@ -228,9 +228,9 @@ proc PrefsDialogGeneral {} {
 
     ttk::label $f.tgui -text [msgcat::mc {GUI}]
     FontMenuButton $f.gui pds9 font font,size font,weight font,slant \
-	[list SetDefaultFont true]
+	"SetDefaultFont true; FontChange"
     ttk::button $f.bgui -text [msgcat::mc {Reset}] \
-	-command ResetDefaultFont
+	-command "ResetDefaultFont; FontChange"
 
     ttk::label $f.ttext -text [msgcat::mc {Text}]
     FontMenuButton $f.text pds9 text,font \
@@ -417,6 +417,8 @@ proc PrefsDialogStartup {} {
 
     grid $f.xpa -padx 2 -pady 2 -sticky w
     grid $f.samp -padx 2 -pady 2 -sticky w
+    grid $f.samphub -padx 2 -pady 2 -sticky w
+    grid $f.sampwebhub -padx 2 -pady 2 -sticky w
 
     pack $w.startup.params -side top -fill both -expand true
 }
