@@ -27,71 +27,6 @@ proc RGBDef {} {
     set rgb(lock,smooth) 0
 }
 
-proc RGBEvalLockCurrent {varname cmd} {
-    global current
-
-    global rgb
-    global crop
-    global cube
-    global bin
-    global scale
-    global colorbar
-    global block
-    global smooth
-
-    RGBEvalLock $varname $current(frame) $cmd
-}
-
-proc RGBEvalLock {varname which cmd} {
-    upvar $varname var
-
-    global rgb
-    global crop
-    global cube
-    global bin
-    global scale
-    global colorbar
-    global block
-    global smooth
-
-    if {$var && [$which get type] == {rgb}} {
-	set ch [$which get rgb channel]
-	foreach cc {red green blue} {
-	    $which rgb channel $cc
-	    eval $cmd
-	}
-	$which rgb channel $ch
-    } else {
-	eval $cmd
-    }
-}
-
-proc RGBEvalLockColorbarCurrent {cmd} {
-    global current
-    
-    RGBEvalLockColorbar $current(frame) $cmd
-}
-
-proc RGBEvalLockColorbar {which cmd} {
-    global current
-    global scale
-    global rgb
-
-    set cb ${which}cb
-    if {$rgb(lock,colorbar) && [$which get type] == {rgb}} {
-	set ch [$which get rgb channel]
-	foreach cc {red green blue} {
-	    $which rgb channel $cc
-	    $cb rgb channel $cc
-	    eval $cmd
-	}
-	$which rgb channel $ch
-	$cb rgb channel $ch
-    } else {
-	eval $cmd
-    }
-}
-
 proc RGBChannel {} {
     global current
 
