@@ -20,7 +20,6 @@ proc TBLGetURL {varname url query} {
 					 -timeout $ihttp(timeout) \
 					 -headers "[ProxyHTTP]"]
 	}]} {
-	    # reset errorInfo (may be set in http::geturl)
 	    global errorInfo
 	    set errorInfo {}
 
@@ -37,7 +36,6 @@ proc TBLGetURL {varname url query} {
 					 [list TBLGetURLFinish $varname] \
 					 -headers "[ProxyHTTP]"]
 	}]} {
-	    # reset errorInfo (may be set in http::geturl)
 	    global errorInfo
 	    set errorInfo {}
 
@@ -731,7 +729,7 @@ proc TBLEditDialogSave {parent} {
 	set flt [$ed(text) get 1.0 end]
 	catch {regsub {\n} $flt " " flt}
 	puts $fp [string trim $flt]
-	catch {close $fp}
+	close $fp
     }
 }
 
@@ -747,7 +745,7 @@ proc TBLEditDialogLoad {parent} {
 	$ed(text) delete 1.0 end
 	$ed(text) insert end [read -nonewline $fp]
 	$ed(text) see end
-	catch {close $fp}
+	close $fp
     }
 }
 
@@ -847,7 +845,7 @@ proc TBLCmdFilterLoad {fn} {
 	set flt [read -nonewline $fp]
 	catch {regsub {\n} $flt " " $flt}
 	set cvar(filter) [string trim $flt]
-	catch {close $fp}
+	close $fp
     }
 }
 
