@@ -28,10 +28,6 @@ proc GetFileFTP {host path fn} {
 	ftp::Type $ftp binary
 	ftp::Get $ftp $path $fn
 	ftp::Close $ftp
-
-	# clear error from tcllib ftp
-	global errorInfo
-	set errorInfo {}
     }
 }
 
@@ -53,17 +49,16 @@ proc GetFileHTTP {url fn} {
 		    -binary 1 \
     		    -timeout $ihttp(timeout) \
 		    -headers "[ProxyHTTP]"} token]} {
-	close $ch
+	catch {close $ch}
+
 	Error "[msgcat::mc {Unable to locate URL}] $url"
 	return
     }
-
-
-    # reset errorInfo (may be set in http::geturl)
     global errorInfo
     set errorInfo {}
 
     close $ch
+
     if {[info exists token]} {
 	if {$foo(authority) == {cda.harvard.edu}} {
 	    upvar 0 $token state
@@ -146,14 +141,14 @@ proc LoadURLFitsHTTP {url layer mode multi} {
 			       -binary 1 \
 			       -timeout $ihttp(timeout) \
 			       -headers "[ProxyHTTP]"]}]} {
-	close $var(ch)
-	Error "[msgcat::mc {Unable to locate URL}] $url"
-    }
+	catch {close $ch}
 
-    # reset errorInfo (may be set in http::geturl)
+	Error "[msgcat::mc {Unable to locate URL}] $url"
+	return
+    }
     global errorInfo
     set errorInfo {}
-
+    
     close $ch
 
     upvar #0 $token t
@@ -341,3 +336,18 @@ proc ProcessURLFitsCmd {varname iname} {
     incr i [expr $urlfits::yycnt-1]
 }
 
+proc LoadURLFitsCmd {url} {
+    global current
+    
+    if {$current(frame) != {}} {
+	switch -- [$current(frame) get type] {
+	    base {set multi 1}
+	    rgb {set multi 0}
+	    3d {set multi 1}
+	}
+    } else {
+	set multi 1
+    }
+
+    LoadURLFits $url {} {} $multi
+}
