@@ -1,4 +1,4 @@
-#  Copyright (C) 1999-2021
+#  Copyright (C) 1999-2023
 #  Smithsonian Astrophysical Observatory, Cambridge, MA, USA
 #  For conditions of distribution and use, see copyright notice in "copyright"
 
@@ -14,6 +14,8 @@ proc CurrentDef {} {
     set current(ext) {}
     set current(cursor) {}
     set current(rgb) red
+    set current(hsv) hue
+    set current(hls) hue
 
     set current(display) single
     set current(mode) none
@@ -67,6 +69,119 @@ proc GetNumCores {} {
     return 1
 }
 
+proc EvalLockCurrent {var cmd} {
+    global current
+
+    EvalLock $var $current(frame) $cmd
+}
+
+proc EvalLock {var which cmd} {
+    global rgb
+    global hsv
+    global hls
+
+    switch [$which get type] {
+	base -
+	3d {eval $cmd}
+	rgb {
+	    if {$rgb($var)} {
+		set ch [$which get rgb channel]
+		foreach cc {red green blue} {
+		    $which rgb channel $cc
+		    eval $cmd
+		}
+		$which rgb channel $ch
+	    } else {
+		eval $cmd
+	    }
+	}
+	hsv {
+	    if {$hsv($var)} {
+		set ch [$which get hsv channel]
+		foreach cc {hue saturation value} {
+		    $which hsv channel $cc
+		    eval $cmd
+		}
+		$which hsv channel $ch
+	    } else {
+		eval $cmd
+	    }
+	}
+	hls {
+	    if {$hls($var)} {
+		set ch [$which get hls channel]
+		foreach cc {hue lightness saturation} {
+		    $which hls channel $cc
+		    eval $cmd
+		}
+		$which hls channel $ch
+	    } else {
+		eval $cmd
+	    }
+	}
+    }
+}
+
+proc EvalLockColorbarCurrent {cmd} {
+    global current
+    
+    EvalLockColorbar $current(frame) $cmd
+}
+
+proc EvalLockColorbar {which cmd} {
+    global rgb
+    global hsv
+    global hls
+
+    set cb ${which}cb
+    switch [$which get type] {
+	base -
+	3d {eval $cmd}
+	rgb {
+	    if {$rgb(lock,colorbar)} {
+		set ch [$which get rgb channel]
+		foreach cc {red green blue} {
+		    $which rgb channel $cc
+		    $cb rgb channel $cc
+		    eval $cmd
+		}
+		$which rgb channel $ch
+		$cb rgb channel $ch
+	    } else {
+		eval $cmd
+	    }
+	}
+	hsv {
+	    if {$hsv(lock,colorbar)} {
+		set ch [$which get hsv channel]
+		foreach cc {hue saturation value} {
+		    $which hsv channel $cc
+		    $cb hsv channel $cc
+		    eval $cmd
+		}
+		$which hsv channel $ch
+		$cb hsv channel $ch
+	    } else {
+		eval $cmd
+	    }
+	}
+	hls {
+	    if {$hls(lock,colorbar)} {
+		set ch [$which get hls channel]
+		foreach cc {hue lightness value} {
+		    $which hls channel $cc
+		    $cb hls channel $cc
+		    eval $cmd
+		}
+		$which hls channel $ch
+		$cb hls channel $ch
+	    } else {
+		eval $cmd
+	    }
+	}
+    }
+}
+
 proc UpdateDS9 {} {
     global ds9
     global current
@@ -115,6 +230,8 @@ proc UpdateDS9 {} {
     UpdateCentroidDialog
     UpdateCubeDialog
     UpdateRGBDialog
+    UpdateHSVDialog
+    UpdateHLSDialog
     Update3DDialog
     UpdateContourDialog
     UpdateGridDialog
@@ -447,6 +564,11 @@ proc ProcessSendCmdSend {ext cmd} {
     }
 }
 
+proc ProcessSendNullCmd {proc id cmd} {
+    Error "[msgcat::mc {Unknown command}]: $cmd"
+    $proc $id {}
+}
+
 proc ProcessSend {proc id sock fn ext rr} {
     if {$fn != {}} {
 	append fn $ext
@@ -573,32 +695,6 @@ proc SetLanguage {ll} {
     }
 }
 
-proc GetEnvHome {} {
-    global env
-    global tcl_platform
-
-    switch $tcl_platform(platform) {
-	unix {
-	    if {[info exists env(HOME)]} {
-		return $env(HOME)
-	    }
-	}
-	windows {
-	    if {[info exists env(HOME)]} {
-		set hh [file normalize [file nativename $env(HOME)]]
-		if {[file isdirectory $hh]} {
-		    return $hh
-		}
-	    }
-	    # this is just a backup, the above should always work
-	    if {[info exists env(HOMEDRIVE)] &&	[info exists env(HOMEPATH)]} {
-		return "$env(HOMEDRIVE)$env(HOMEPATH)"
-	    }
-	}
-    }
-    return {}
-}
-
 proc InitTempDir {} { 
     global ds9
     global env
@@ -848,13 +944,13 @@ proc AboutBoxDefault {} {
 
     # Param
     set f [ttk::frame $w.param]
-    canvas $f.c -background white -height 400 -width 500
+    canvas $f.c -background white -height 250 -width 500
     pack $f.c -fill both -expand true
     
     set ed(sun) [image create photo -file $ds9(root)/doc/sun.png]
     
     $f.c create image 0 0 -image $ed(sun) -anchor nw
-    $f.c create text 120 22 -text $help(about) -anchor nw -width 400
+    $f.c create text 120 12 -text $help(about) -anchor nw -width 400
 
     # Buttons
     set f [ttk::frame $w.buttons]
@@ -882,13 +978,13 @@ proc QuitDS9 {} {
     # shutdown SAMP
     global samp
     if {[info exists samp]} {
-	catch {SAMPDisconnect 0}
+	catch {SAMPDisconnect}
     }
 
     # shutdown SAMPHUB
     global samphub
     if {[info exists samphub]} {
-	catch {SAMPHubStop 0}
+	catch {SAMPHubStop}
     }
     
     # close IIS ports
@@ -1181,61 +1277,6 @@ proc DisplayLog {item} {
     SimpleTextDialog ftptxt [msgcat::mc {Message Log}] 80 40 append bottom $item
 }
 
-proc ParseURL {url varname} {
-    upvar $varname r
-
-    set r(scheme) {}
-    set r(authority) {}
-    set r(path) {}
-    set r(query) {}
-    set r(fragment) {}
-    set exp {^(([^:/?#]+):)?(//([^/?#]*))?([^?#]*)(\?([^#]*))?(#(.*))?}
-
-    if {![regexp -nocase $exp $url x a r(scheme) c r(authority) r(path) f r(query) h r(fragment)]} {
-	return 0
-    }
-
-    # check for windows disk drives
-    global tcl_platform
-    switch $tcl_platform(platform) {
-	unix {
-	    switch -- $r(scheme) {
-		zipfs {
-		    # special case for zipfs
-		    set r(path) "$r(scheme):$r(path)"
-		    set r(scheme) {}
-		}
-		ftp {
-		    # strip any username/passwd
-		    set id [string first {@} $r(authority)]
-		    if { $id != -1} {
-			set r(authority) [string range $r(authority) [expr $id+1] end]
-		    }
-		}
-	    }
-	}
-	windows {
-	    switch -- $r(scheme) {
-		{} -
-		ftp -
-		http -
-		https -
-		file {
-		    if {[regexp {/([A-Z]:)(/.*)} $r(path) a b c]} {
-			set r(path) "$b$c"
-		    }
-		}
-		default {
-		    set r(path) "$r(scheme):$r(path)"
-		    set r(scheme) {}
-		}
-	    }
-	}
-    }
-
-    return 1
-}
-
 proc BreakUp {str} {
     set r {}
     set l [string length $str]
@@ -1311,7 +1352,7 @@ proc ConfigHTTP {} {
     http::config -useragent ds9
 
     # set up tls
-    http::register https 443 [list ::tls::socket -tls1 1]
+    http::register https 443 [list ::tls::socket -tls1 true]
 
     # set the proxy if requested
     if {$phttp(proxy)} {
@@ -1586,8 +1627,7 @@ proc ProcessConsoleCmd {varname iname} {
     OpenConsole
 
     # ignore error message about ActiveTcl
-    global ds9
-    InitError $ds9(msg,src)
+    InitError tcl
 }
 
 proc ProcessCursorCmd {varname iname} {
@@ -1812,11 +1852,3 @@ proc ProcessSendVersionCmd {proc id param {sock {}} {fn {}}} {
     $proc $id "$ds9(title) $ds9(version,display)\n"
 }
 
-proc XMLQuote {val} {
-    return [string map {& &amp; < &lt; > &gt; \' &apos; \" &quot;} $val]
-}
-
-proc XMLUnQuote {val} {
-    return [string map {&amp; & &lt; < &gt; > &apos; \' &quot; \"} $val]
-}
-
