@@ -1,4 +1,4 @@
-#  Copyright (C) 1999-2018
+#  Copyright (C) 1999-2021
 #  Smithsonian Astrophysical Observatory, Cambridge, MA, USA
 #  For conditions of distribution and use, see copyright notice in "copyright"
 
@@ -73,7 +73,7 @@ proc VOTRead {t fn} {
     }
 }
 
-proc VOTWrite {t fn} {
+proc VOTWrite {t fn {offset 0}} {
     upvar #0 $t T
     global $t
 
@@ -169,7 +169,7 @@ proc VOTWrite {t fn} {
     puts $fp {<DATA>}
     puts $fp {<TABLEDATA>}
 
-    for {set rr 1} {$rr <= $nr} {incr rr} {
+    for {set rr [expr 1+$offset]} {$rr <= $nr} {incr rr} {
 	puts -nonewline $fp {<TR>}
 	for {set cc 1} {$cc <= $nc} {incr cc} {
 	    puts -nonewline $fp "<TD>[XMLQuote $T($rr,$cc)]</TD>"
@@ -207,6 +207,9 @@ proc VOTCharCB {t data} {
 		    VOTABLE -
 		    RESOURCE -
 		    TABLE {
+			# don't save general description
+			# wait until FIELD
+			if {0} {
 			foreach ll [split [string trim $data] "\n"] {
 			    incr ${t}(HLines)
 			    set n $T(HLines)
@@ -216,6 +219,7 @@ proc VOTCharCB {t data} {
 				set T(H_$n) "# $ll"
 			    }
 			}
+			}
 		    }
 		    FIELD {
 			set T(Description) \
@@ -291,10 +295,6 @@ proc VOTElemStartCB {t name attlist args} {
 	    # ok, we now need to build the header
 	    starbase_colmap $t
 
-	    incr ${t}(HLines)
-	    set n $T(HLines)
-	    set T(H_$n) {}
-
 	    set nc $T(Ncols)
 	    for {set cc 1} {$cc <= $nc} {incr cc} {
 		set hdr "# name=[lindex $T(Header) [expr $cc-1]] "
@@ -360,12 +360,9 @@ proc VOTElemStartCB {t name attlist args} {
 	    set n $T(HLines)
 	    set T(H_$n) [join $T(Header)]
 
-	    set T(Dashes) [regsub -all {[A-Za-z0-9]} $T(H_$n) {-}]
-	    set T(Ndshs) [llength $T(Header)]
-
 	    incr ${t}(HLines)
 	    set n $T(HLines)
-	    set T(H_$n) [join $T(Dashes)]
+	    set T(H_$n) [regsub -all {[A-Za-z0-9]} $T(Header) {-}]
 	}
 	TR {
 	    incr ${t}(Nrows)
