@@ -13,7 +13,7 @@ proc WCSDef {} {
     set iwcs(mb) .wcsmb
 
     set wcs(system) wcs
-    set wcs(sky) fk5
+    set wcs(sky) icrs
     set wcs(skyformat) sexagesimal
 
     # temp
@@ -51,7 +51,8 @@ proc UpdateWCS {} {
     set grid(system) $wcs(system)
     set grid(sky) $wcs(sky)
     set grid(skyformat) $wcs(skyformat)
-    GridUpdateCurrent
+    UpdateGridCurrent
+    UpdateGridDialog
 
     # panzoom dialog
     global panzoom
@@ -84,6 +85,16 @@ proc UpdateWCS {} {
     set rgb(system) $wcs(system)
     RGBSystem
 
+    # hls
+    global hls
+    set hls(system) $wcs(system)
+    HLSSystem
+
+    # hsv
+    global hsv
+    set hsv(system) $wcs(system)
+    HSVSystem
+
     # regions
     global marker
     set marker(system) $wcs(system)
@@ -569,10 +580,10 @@ proc WCSDialog {} {
 proc WCSApplyDialog {} {
     global dwcs
     global current
-    global rgb
 
     if {$current(frame) != {}} {
-	RGBEvalLock rgb(lock,wcs) $current(frame) "$current(frame) wcs replace text $dwcs(ext) \{\{[WCSFromVar]\}\}"
+	EvalLock lock,wcs $current(frame) \
+	    "$current(frame) wcs replace text $dwcs(ext) \{\{[WCSFromVar]\}\}"
 	UpdateWCS
 	CATUpdateWCS
 	FPUpdateWCS
@@ -582,10 +593,10 @@ proc WCSApplyDialog {} {
 proc WCSResetDialog {} {
     global dwcs
     global current
-    global rgb
 
     if {$current(frame) != {}} {
-	RGBEvalLock rgb(lock,wcs) $current(frame) [list $current(frame) wcs reset $dwcs(ext)]
+	EvalLock lock,wcs $current(frame) \
+	    [list $current(frame) wcs reset $dwcs(ext)]
 	UpdateWCS
 	CATUpdateWCS
 	FPUpdateWCS
@@ -628,7 +639,7 @@ proc WCSSaveFile {fn wcs} {
 	return
     }
     puts $fp $wcs
-    catch {close $fp}
+    close $fp
 }
 
 proc WCSLoadDialog {} {
@@ -647,13 +658,12 @@ proc WCSLoadFile {fn} {
 	    return
 	}
 	WCSToVar [read -nonewline $fp]
-	catch {close $fp}
+	close $fp
     }
 }
 
 proc UpdateWCSDialog {} {
     global iwcs
-    global current
 
     global debug
     if {$debug(tcl,update)} {
@@ -686,7 +696,6 @@ proc ConfigWCSDialog {} {
     global wcs
     global iwcs
     global dwcs
-    global current
 
     global debug
     if {$debug(tcl,update)} {
@@ -1188,15 +1197,13 @@ proc ProcessWCSCmd {varname iname sock fn} {
 }
 
 proc WCSCmdReset {ext} {
-    global rgb
     global current
     
     if {$current(frame) == {}} {
 	return
     }
 
-    RGBEvalLock rgb(lock,wcs) $current(frame) \
-	[list $current(frame) wcs reset $ext]
+    EvalLock lock,wcs $current(frame) [list $current(frame) wcs reset $ext]
     UpdateWCS
     CATUpdateWCS
     FPUpdateWCS
@@ -1205,7 +1212,6 @@ proc WCSCmdReset {ext} {
 
 proc WCSCmdLoad {cmd ext} {
     global current
-    global rgb
     global parse
 
     if {$current(frame) == {}} {
@@ -1213,9 +1219,11 @@ proc WCSCmdLoad {cmd ext} {
     }
 
     if {$parse(sock) != {}} {
-	RGBEvalLock rgb(lock,wcs) $current(frame) [list $current(frame) wcs $cmd $ext $parse(sock)]
+	EvalLock lock,wcs $current(frame) \
+	    [list $current(frame) wcs $cmd $ext $parse(sock)]
     } elseif {$parse(fn) != {}} {
-	RGBEvalLock rgb(lock,wcs) $current(frame) "$current(frame) wcs $cmd $ext \{\{$parse(fn)\}\}"
+	EvalLock lock,wcs $current(frame) \
+	    "$current(frame) wcs $cmd $ext \{\{$parse(fn)\}\}"
     }
 
     UpdateWCS
@@ -1226,13 +1234,13 @@ proc WCSCmdLoad {cmd ext} {
 
 proc WCSCmdLoadFn {cmd ext fn} {
     global current
-    global rgb
 
     if {$current(frame) == {}} {
 	return
     }
 
-    RGBEvalLock rgb(lock,wcs) $current(frame) "$current(frame) wcs $cmd $ext \{\{$fn\}\}"
+    EvalLock lock,wcs $current(frame) \
+	"$current(frame) wcs $cmd $ext \{\{$fn\}\}"
     UpdateWCS
     CATUpdateWCS
     FPUpdateWCS
@@ -1272,5 +1280,6 @@ proc ProcessAlignCmd {varname iname} {
 
 proc ProcessSendAlignCmd {proc id param {sock {}} {fn {}}} {
     global current
+
     $proc $id [ToYesNo $current(align)]
 }
