@@ -23,7 +23,6 @@ class Colorbar : public ColorbarBase {
 
  protected:
   List<ColorMapInfo> cmaps;
-  int cmapid_;
 
   List<ColorTag> ctags;
   int ctagid_;
@@ -42,8 +41,8 @@ class Colorbar : public ColorbarBase {
   void psVert(ostream&, Filter&, int, int);
 
  protected:
-  int calcContrastBias(int);
-  void loadDefaultCMaps();
+  void loadDefaultCmaps();
+  int initColormap();
   void reset();
   void updateColorCells();
 
@@ -56,9 +55,7 @@ class Colorbar : public ColorbarBase {
 
  public:
   Colorbar(Tcl_Interp*, Tk_Canvas, Tk_Item*);
-  virtual ~Colorbar();
 
-  int cmapid() {return cmapid_++;}
   int ctagid() {return ctagid_++;}
 
   // commands
