@@ -1,4 +1,4 @@
-// Copyright (C) 1999-2018
+// Copyright (C) 1999-2021
 // Smithsonian Astrophysical Observatory, Cambridge, MA, USA
 // For conditions of distribution and use, see copyright notice in "copyright"
 
@@ -33,10 +33,6 @@ protected:
   virtual void renderPSDraw(int);
   void renderPSFillDraw(int);
 
-#ifdef MAC_OSX_TK
-  void renderMACOSX();
-  virtual void renderMACOSXDraw(Vector*);
-#endif
 #ifdef __WIN32
   void renderWIN32();
   virtual void renderWIN32Draw(Vector*);
