@@ -1,4 +1,4 @@
-// Copyright (C) 1999-2018
+// Copyright (C) 1999-2021
 // Smithsonian Astrophysical Observatory, Cambridge, MA, USA
 // For conditions of distribution and use, see copyright notice in "copyright"
 
@@ -28,9 +28,6 @@ class Grid {
 
   virtual void x11() =0;
   virtual void ps(PSColorSpace) =0;
-#ifdef MAC_OSX_TK
-  virtual void macosx() =0;
-#endif
 #ifdef __WIN32
   virtual void win32() =0;
 #endif
