@@ -1,4 +1,4 @@
-// Copyright (C) 1999-2018
+// Copyright (C) 1999-2021
 // Smithsonian Astrophysical Observatory, Cambridge, MA, USA
 // For conditions of distribution and use, see copyright notice in "copyright"
 
@@ -32,12 +32,6 @@ class Point : public Marker {
   void renderPSBox(int);
   void renderPSLineDash();
 
-#ifdef MAC_OSX_TK
-  void renderMACOSXCircle(int);
-  void renderMACOSXBox();
-  void renderMACOSXLineDash();
-#endif
-
 #ifdef __WIN32
   void renderWIN32Circle(int);
   void renderWIN32Box();
@@ -65,10 +59,6 @@ class Point : public Marker {
   void renderX(Drawable, Coord::InternalSystem, RenderMode);
   void renderPS(PSColorSpace mode);
 
-#ifdef MAC_OSX_TK
-  void renderMACOSX();
-#endif
-
 #ifdef __WIN32
   void renderWIN32();
 #endif
