@@ -9,12 +9,11 @@
 
 class Magnifier : public Widget {
 private:
-  Pixmap thumbnail;        // current gterm thumbnail pixmap
+  int use_;                // use or cleared?
   double crosshairSize;    // size of crosshair (diameter)
   double crosshairAngle;   // angle of rotation (radians)
   GC crosshairGC;          // gc for crosshairs
   int useCrosshair;        // flag to render crosshair
-  int needsUpdate;         // flag to indicate update needed
 
 private:
   int updatePixmap(const BBox&); // renders image/graphics into pixmap
