@@ -27,12 +27,22 @@ using namespace std;
 class Attribute;
 
 // exchange pointer between widgets
-extern void* cellsptr_;
 extern void* frameptr_;
+
 extern void* fitsimageptr_;
+extern void* fitsimageparentptr_;
+
+extern void* cellsptr_;
+extern void* cellsparentptr_;
+
 extern void* colormaplevelptr_;
+extern void* colormaplevelparentptr_;
+
 extern void* magnifierptr_;
+extern void* magnifierparentptr_;
+
 extern void* pannerptr_;
+extern void* pannerparentptr_;
 
 // General Defines
 
